@@ -1,12 +1,16 @@
-/* $Id: connectionManager.h,v 1.5 2002/11/24 04:40:41 fesnel Exp $
+/* $Id: connectionManager.h,v 1.7 2003/02/23 00:42:45 cfreeze Exp $
  */
 
-#ifndef _CONNECTIONMANAGER_H_
+#if !defined _CONNECTIONMANAGER_H_
 #define  _CONNECTIONMANAGER_H_
 
+//Forward Declarations
+class connection;
+
 class connectionManager {
 
 public:
+	connectionManager();
 	~connectionManager();
 
 	class connection * get_conn(int sock);
@@ -23,4 +27,4 @@ private:
 	list<connection *> Connections;
 };
 
-#endif
+#endif //  _CONNECTIONMANAGER_H_
