@@ -1,10 +1,10 @@
-/* $Id: umail.h,v 1.18 2002/11/12 01:25:58 fesnel Exp $ */
+/* $Id: umail.h,v 1.24 2004/01/02 04:12:03 fesnel Exp $ */
 /*******************************************************************************
  *   This program is part of a library used by the Archimedes email client     * 
  *                                                                             *
  *   Copyright : (C) 1995-1998 Gennady B. Sorokopud (gena@NetVision.net.il)    *
  *               (C) 1995 Ugen. J. S. Antsilevich (ugen@latte.worldbank.org)   *
- *               (C) 1998-2002 by the Archimedes Project                       *
+ *               (C) 1998-2004 by the Archimedes Project                       *
  *                   http://sourceforge.net/projects/archimedes                *
  *                                                                             *
  *             --------------------------------------------                    *
@@ -26,10 +26,11 @@
  ******************************************************************************/
 
 #ifndef     UMAIL_H
+
     #define     UMAIL_H
 
     #ifdef HAVE_CONFIG_H
-    #include <config.h>
+        #include <config.h>
     #endif
 
     #ifdef __linux__
@@ -42,7 +43,7 @@
         #include <limits.h>
     #endif
     #include <signal.h>
-    #if STDC_HEADERS || defined(USE_STDARG)
+    #if STDC_HEADERS || defined(HAVE_STDARG_H)
         #include <stdarg.h>
     #else
         #include <varargs.h>
@@ -209,7 +210,7 @@ extern Pixmap icon_ABook, icon_ABook_sh;
 void sig_timers();
 
 /* faces (picons) staff */
-    #ifdef FACES
+    #ifdef WITH_FACES
 char *xbm_to_face();
 char *get_msg_face(struct _mail_msg *msg);
 void update_faces(struct _mail_msg *msg);
@@ -434,6 +435,10 @@ struct _spool_src *get_msg_spoolsrc(struct _mail_msg *msg);
 struct _pop_src *get_msg_popsrc(struct _mail_msg *msg);
 struct _imap_src *get_msg_imapsrc(struct _mail_msg *msg);
 
+/* character set handling */
+int charset_style_from_code(int code);
+int charset_size_from_code(int code);
+
 void set_menu_imap();
 
 int text_dbl_call(FL_OBJECT *obj, char *word, int key, int r, int c);
