@@ -1,10 +1,10 @@
-/* $Id: cache.cpp,v 1.13 2002/11/24 18:44:40 fesnel Exp $ */
+/* $Id: cache.cpp,v 1.16 2004/01/02 03:54:01 fesnel Exp $ */
 /*******************************************************************************
  *   This program is part of a library used by the Archimedes email client     * 
  *                                                                             *
  *   Copyright : (C) 1995-1998 Gennady B. Sorokopud (gena@NetVision.net.il)    *
  *               (C) 1995 Ugen. J. S. Antsilevich (ugen@latte.worldbank.org)   *
- *               (C) 1998-2002 by the Archimedes Project                       *
+ *               (C) 1998-2004 by the Archimedes Project                       *
  *                   http://sourceforge.net/projects/archimedes                *
  *                                                                             *
  *             --------------------------------------------                    *
@@ -242,13 +242,14 @@ int open_cache(struct _mail_folder *folder) {
 char *get_cache_file(struct _mail_folder *folder, int type) {
 	static char cname[300 + MAX_FOLD_NAME_LEN];
 	char buf[MAX_FOLD_NAME_LEN];
-	char *p, *cdir;
+	char *p;
+    string sCacheDir;
 	int ctype = (folder->type & 0x0f) | (folder->level << 4);
 
 	if(Config.exist("cachedir"))
-		cdir = Config.getCString("cachedir", configdir);
+		sCacheDir = Config.get("cachedir", configdir);
 	else
-		cdir = configdir;
+		sCacheDir = configdir;
 
 	snprintf(buf, sizeof(buf), "%s", folder->name(folder));
 	if(folder->pfold && (folder->hdelim == '/')) {
@@ -258,22 +259,22 @@ char *get_cache_file(struct _mail_folder *folder, int type) {
 
 	switch(type) {
 		case 0:
-			snprintf(cname, sizeof(cname), "%s/%s/%02x%s", cdir, CACHE_DIR,
+			snprintf(cname, sizeof(cname), "%s/%s/%02x%s", sCacheDir.c_str(), CACHE_DIR,
 					 ctype, buf);
 			break;
 
 		case 1:
-			snprintf(cname, sizeof(cname), "%s/%s/%02x%s.db", cdir, CACHE_DIR,
+			snprintf(cname, sizeof(cname), "%s/%s/%02x%s.db", sCacheDir.c_str(), CACHE_DIR,
 					 ctype, buf);
 			break;
 
 		case 2:
-			snprintf(cname, sizeof(cname), "%s/%s/%02x%s.dir", cdir, CACHE_DIR,
+			snprintf(cname, sizeof(cname), "%s/%s/%02x%s.dir", sCacheDir.c_str(), CACHE_DIR,
 					 ctype, buf);
 			break;
 
 		case 3:
-			snprintf(cname, sizeof(cname), "%s/%s/%02x%s.pag", cdir, CACHE_DIR,
+			snprintf(cname, sizeof(cname), "%s/%s/%02x%s.pag", sCacheDir.c_str(), CACHE_DIR,
 					 ctype, buf);
 			break;
 
@@ -288,7 +289,7 @@ int init_cache() {
 
 	if(Config.exist("cachedir"))
 		snprintf(cname, sizeof(cname), "%s/%s",
-				 Config.getCString("cachedir", configdir),
+				 Config.get("cachedir", configdir).c_str(),
 				 CACHE_DIR);
 	else
 		snprintf(cname, sizeof(cname), "%s/%s", configdir, CACHE_DIR);
