@@ -1,10 +1,10 @@
-/* $Id: cfgfile.cpp,v 1.15.2.1 2003/02/15 00:40:12 cfreeze Exp $ */
+/* $Id: cfgfile.cpp,v 1.23 2004/01/02 03:54:01 fesnel Exp $ */
 /*******************************************************************************
  *   This program is part of a library used by the Archimedes email client     * 
  *                                                                             *
  *   Copyright : (C) 1995-1998 Gennady B. Sorokopud (gena@NetVision.net.il)    *
  *               (C) 1995 Ugen. J. S. Antsilevich (ugen@latte.worldbank.org)   *
- *               (C) 1998-2002 by the Archimedes Project                       *
+ *               (C) 1998-2004 by the Archimedes Project                       *
  *                   http://sourceforge.net/projects/archimedes                *
  *                                                                             *
  *             --------------------------------------------                    *
@@ -25,7 +25,9 @@
  *                                                                             *
  ******************************************************************************/
 
-#include <fmail.h>
+#include "config.h"
+
+#include "fmail.h"
 #include "cfgfile.h"
 
 //#define CFGFILE_DEBUG
@@ -34,7 +36,7 @@
 
 extern struct _xfdef xfdefs;
 
-#if STDC_HEADERS || defined(USE_STDARG)
+#if STDC_HEADERS || defined(HAVE_STDARG_H)
 inline void cfg_debug(int status, char *fmt, ...)
 #else
 inline void cfg_debug(int status, char *fmt, va_dcl va_list)
@@ -42,7 +44,7 @@ inline void cfg_debug(int status, char *fmt, va_dcl va_list)
 {
 	va_list ap;
 
-#if STDC_HEADERS || defined(USE_STDARG)
+#if STDC_HEADERS || defined(HAVE_STDARG_H)
 	va_start(ap, fmt);
 #else
 	va_start(ap);
@@ -97,6 +99,7 @@ cfgfile::cfgfile() {
 	strcpy(fname,"");
 	changedKeys = false;
 	changedFlags = false;
+    clear();
 }
 
 cfgfile::~cfgfile() {
@@ -119,28 +122,32 @@ string cfgfile::get(string key, string def)
 {
 	string val = find(key);
 
-	if ( val != "" ) {
+	if(val != "") {
 		return val;
-	}
-	else {
+	} else {
 		return def;
 	}
-	
 }
 
-char * cfgfile::getCString(string key, string def)
+string cfgfile::get(string ln, string def, int return_default)
 {
-	m_sSafeReturn = get(key,def).c_str();
-	return const_cast<char*>(m_sSafeReturn.c_str());
+	if(return_default)
+        return def;
+    else
+        return get(ln,def);
 }
 
 bool cfgfile::add(string key, string val)
 {
-	cfg_debug(CFG_DEBUG, "\nTrying add(%s) -> %s ... ",key.c_str(), val.c_str());
 
-	Map[key] = val;
-
-	return true;
+    if((key.size() != 0) && (val.size() != 0)) {
+	    cfg_debug(CFG_DEBUG, "\nadd(%s) -> %s ... ",key.c_str(), val.c_str());
+        //cerr << "Adding (" << sKey << ") (" << sValue << ")\n";
+	    Map[key] = val;
+	    return true;
+    } else {
+        return false;
+    }
 }
 
 string cfgfile::find(string key)
@@ -300,14 +307,31 @@ int cfgfile::save_file(char * file, int ask)
 /*
  * This function reads a single config file line and
  * does The Right Thing(tm) with it by parsing it and adding it to
- * the config map
+ * the config map. Assumes buf has no newline character at end.
  */
 void cfgfile::addLine(char *buf)
 {
 	string configString(buf);
-	string::size_type l = configString.size();
-	string::size_type i = configString.find("=");
-	add(configString.substr(0, i), configString.substr(i + 1, l - 1));
+	string::size_type iSize;
+	string::size_type iSpot;
+    string sKey;
+    string sValue;
+
+	iSize = configString.size();
+
+    if(iSize >= 3) { // k=v at min
+	    iSpot = configString.find("=");
+
+        if(iSpot != string::npos) {
+            sKey = configString.substr(0,iSpot);
+            sValue = configString.substr(iSpot + 1, iSize - iSpot);
+            //sValue = configString.substr(iSpot + 1, iSize - 1);
+
+	        add(sKey, sValue);
+        }
+    }
+
+    return;
 }
 
 
@@ -319,7 +343,6 @@ int cfgfile::load(char * fn)
 {
 	FILE *f;
 	char buf[SLEN + 1];
-	char *p;
 
 	destroy();
 
@@ -334,34 +357,21 @@ int cfgfile::load(char * fn)
 
 	assert(cfile != NULL);
 	while(fgets(buf,SLEN,cfile) != NULL) {
-		if(buf[0] == '#')
-			continue;
-
-		if(strchr(buf, '=') == NULL)
-			continue;
-
-		strip_newline(buf);
-		addLine(buf);
+		if(buf[0] != '#') { //Skip Comments
+		    strip_newline(buf);
+		    addLine(buf);
+        }
 	}
-
 	unlock(fn);
 	cfg_debug(CFG_STATUS, " completed. [%i]\n",Map.size());
 
 	cfg_debug(CFG_STATUS, "\nLoading System Override Settings...");
 	if((f = fopen(GLOBAL_MAILRC, "r")) != NULL) {
 		while(fgets(buf, SLEN, f) != NULL) {
-			if(buf[0] == '#')
-				continue;
-
-			if((p = strchr(buf, '=')) == NULL)
-				continue;
-			*p = '\0';
-
-			if(find(buf).c_str() != NULL)
-				continue;
-			*p = '=';
-			strip_newline(buf);
-			addLine(buf);
+		    if(buf[0] != '#') { //Skip Comments
+			    strip_newline(buf);
+			    addLine(buf);
+            }
 		}
 		fclose(f);
 	}
@@ -446,14 +456,6 @@ string cfgfile::getStringDefault(string ln, string def, int return_default)
 		return getString(ln,def);
 }
 
-char * cfgfile::getCStringDefault(string ln, string def, int return_default)
-{
-	if(return_default)
-		return (char *)def.c_str();
-	else
-		return (char *)getString(ln,def).c_str();
-}
-
 int cfgfile::getInt(string key,int def) {
 
 	string val = find(key);
@@ -641,3 +643,9 @@ void cfgfile::read_xfdefaults()
 	return;
 #endif
 }
+
+cfgfile & cfgfile::Singleton() {
+    static cfgfile ConfigFile;
+
+    return ConfigFile;
+}
