@@ -1,10 +1,10 @@
-/* $Id: cfgfile.h,v 1.12.2.1 2003/02/15 00:40:13 cfreeze Exp $ */
+/* $Id: cfgfile.h,v 1.19 2004/01/02 03:54:01 fesnel Exp $ */
 /*******************************************************************************
  *   This program is part of a library used by the Archimedes email client     * 
  *                                                                             *
  *   Copyright : (C) 1995-1998 Gennady B. Sorokopud (gena@NetVision.net.il)    *
  *               (C) 1995 Ugen. J. S. Antsilevich (ugen@latte.worldbank.org)   *
- *               (C) 1998-2002 by the Archimedes Project                       *
+ *               (C) 1998-2004 by the Archimedes Project                       *
  *                   http://sourceforge.net/projects/archimedes                *
  *                                                                             *
  *             --------------------------------------------                    *
@@ -30,22 +30,23 @@
 
 using namespace std;
 
+#include <string>
+
 #include <cassert>
 
+#include <config.h>
 #include <umail.h>
 
 #define SECFILEMODE 00600	 /* secure mode on file */
-//#define HASHMINSIZE  128	 /* don't make hash less then this */
 
 #ifdef ARCHIMEDES
-#define GLOBAL_MAILRC 	"/etc/archimedes.mailrc" /* global configuration file */
-#define GLOBAL_DEFAULTS	"/etc/archimedes.defaults"   /* global defaults file */
+    #define GLOBAL_MAILRC 	"/etc/archimedes.mailrc" /* global configuration file */
+    #define GLOBAL_DEFAULTS	"/etc/archimedes.defaults"   /* global defaults file */
 #endif
 
-
 #ifdef XFMAIL
-#define GLOBAL_MAILRC 	"/etc/xfmail.mailrc" /* global configuration file */
-#define GLOBAL_DEFAULTS	"/etc/xfmail.defaults"   /* global defaults file */
+    #define GLOBAL_MAILRC 	"/etc/xfmail.mailrc" /* global configuration file */
+    #define GLOBAL_DEFAULTS	"/etc/xfmail.defaults"   /* global defaults file */
 #endif
 
 typedef map<string, string> mapType;
@@ -55,8 +56,10 @@ class cfgfile {
 public:
 
 	cfgfile();
+	cfgfile(cfgfile const &config);
+
 	~cfgfile();
-	cfgfile(cfgfile const &config); //copy constructor (NEW)
+
 	cfgfile const &operator= (cfgfile const &rhs);
 
 	int save(int ask);
@@ -73,14 +76,15 @@ public:
 	bool set(string key, string val);
 	bool set(string key, int val);
 	bool remove(string key);
-	char * getCString(string key, string def);
 	string get(string key, string def);
-	char * getCStringDefault(string ln, string def, int return_default);
+    string get(string ln, string def, int return_default);
 	string getString(string ln,string def);
 	string getStringDefault(string ln, string def, int return_default);
 
 	void print();
 
+    cfgfile & Singleton();
+
 private:
 
 	unsigned int hash(char * cfgstr);
@@ -101,8 +105,6 @@ private:
 
 	mapType Map;
 
-    string m_sSafeReturn;
-
 };
 
 #endif
