@@ -1,10 +1,10 @@
-/* $Id: connectionManager.cpp,v 1.7 2002/11/24 04:39:36 fesnel Exp $ */
+/* $Id: connectionManager.cpp,v 1.16 2004/01/02 03:54:01 fesnel Exp $ */
 /*******************************************************************************
  *   This program is part of a library used by the Archimedes email client     * 
  *                                                                             *
  *   Copyright : (C) 1995-1998 Gennady B. Sorokopud (gena@NetVision.net.il)    *
  *               (C) 1995 Ugen. J. S. Antsilevich (ugen@latte.worldbank.org)   *
- *               (C) 1998-2002 by the Archimedes Project                       *
+ *               (C) 1998-2004 by the Archimedes Project                       *
  *                   http://sourceforge.net/projects/archimedes                *
  *                                                                             *
  *             --------------------------------------------                    *
@@ -25,11 +25,18 @@
  *                                                                             *
  ******************************************************************************/
 
-#include <fmail.h>
-
+#include "fmail.h"
+#include "openssl.h"
 #include "connection.h"
+#include "connection_ssl.h"
 #include "connectionManager.h"
 
+connectionManager::connectionManager()
+{
+#if defined WITH_SSL
+    init_SSL();
+#endif
+}
 
 connectionManager::~connectionManager()
 {
@@ -74,8 +81,7 @@ void connectionManager::del_cinfo(int sock) {
 
 	if((conn = get_conn(sock)) != NULL) {
 		if(logging & LOG_NET)
-			display_msg(MSG_LOG, "connect", "Disconnected from %s",
-conn->getHost().c_str());
+			display_msg(MSG_LOG, "connect", "Disconnected from %s", conn->getHost().c_str());
 		Connections.remove(conn);
 		delete conn;
 	} else {
@@ -95,6 +101,7 @@ int connectionManager::host_connect(char hostname[MAX_HOST], char *service, char
 	char c_prot[6];
 	char *p;
 	int pport, res;
+    class connection_ssl * conn = NULL;
 
 	if(!hostname)
 		strcpy(c_host, "127.0.0.1");
@@ -138,7 +145,8 @@ int connectionManager::host_connect(char hostname[MAX_HOST], char *service, char
 		return -1;
 	}
 
-	if((new_cinfo(sock, c_host)) == NULL) {
+	conn = (connection_ssl *) new_cinfo(sock, c_host);
+	if(conn == NULL) {
 		close(sock);
 		return -1;
 	}
@@ -257,7 +265,6 @@ int connectionManager::get_ipc_sock(struct sockaddr_in *sin) {
 		return -1;
 	}
 
-	//if(getsockname(sock, (struct sockaddr *) sin, (socklen_t *) & sinlen)
 	if(getsockname(sock, (struct sockaddr *) sin, (unsigned int *) & sinlen)
 	   < 0) {
 		display_msg(MSG_LOG, "ipc", "getsockname failed");
