@@ -1,10 +1,10 @@
-/* $Id: debug.h,v 1.6 2002/01/26 03:14:53 fesnel Exp $ */
+/* $Id: debug.h,v 1.9 2004/01/02 03:54:01 fesnel Exp $ */
 /*******************************************************************************
  *   This program is part of a library used by the Archimedes email client     * 
  *                                                                             *
  *   Copyright : (C) 1995-1998 Gennady B. Sorokopud (gena@NetVision.net.il)    *
  *               (C) 1995 Ugen. J. S. Antsilevich (ugen@latte.worldbank.org)   *
- *               (C) 1998-2002 by the Archimedes Project                       *
+ *               (C) 1998-2004 by the Archimedes Project                       *
  *                   http://sourceforge.net/projects/archimedes                *
  *                                                                             *
  *             --------------------------------------------                    *
@@ -37,7 +37,7 @@
 
 
 /* Debug print function.  Output on stderr debugging messages. */
-#if STDC_HEADERS || defined(USE_STDARG)
+#if STDC_HEADERS || defined(HAVE_STDARG_H)
 void _debugpf(char *fmt, ...);
 #else
 void _debugpf(char *fmt, va_dcl va_list);
