@@ -1,10 +1,10 @@
-/* $Id: fldap.h,v 1.5 2002/01/26 03:14:53 fesnel Exp $ */
+/* $Id: fldap.h,v 1.8 2004/01/02 03:54:01 fesnel Exp $ */
 /*******************************************************************************
  *   This program is part of a library used by the Archimedes email client     * 
  *                                                                             *
  *   Copyright : (C) 1995-1998 Gennady B. Sorokopud (gena@NetVision.net.il)    *
  *               (C) 1995 Ugen. J. S. Antsilevich (ugen@latte.worldbank.org)   *
- *               (C) 1998-2002 by the Archimedes Project                       *
+ *               (C) 1998-2004 by the Archimedes Project                       *
  *                   http://sourceforge.net/projects/archimedes                *
  *                                                                             *
  *             --------------------------------------------                    *
@@ -27,7 +27,7 @@
 
 #include <fmail.h>
 
-#ifdef HAVE_LDAP
+#ifdef WITH_LDAP
 
 #ifndef LDAP_H_
 #define LDAP_H_
@@ -50,5 +50,5 @@ void close_LDAP(void);
 struct _mail_addr * find_ldap_expansion(char * name);
 
 #endif /* LDAP_H_ */
-#endif /* HAVE_LDAP */
+#endif /* WITH_LDAP */
 
