@@ -1,10 +1,10 @@
-/* $Id: fmail.h,v 1.40 2003/01/16 18:04:30 fesnel Exp $ */
+/* $Id: fmail.h,v 1.49 2004/01/02 03:54:01 fesnel Exp $ */
 /*******************************************************************************
  *   This program is part of a library used by the Archimedes email client     * 
  *                                                                             *
  *   Copyright : (C) 1995-1998 Gennady B. Sorokopud (gena@NetVision.net.il)    *
  *               (C) 1995 Ugen. J. S. Antsilevich (ugen@latte.worldbank.org)   *
- *               (C) 1998-2002 by the Archimedes Project                       *
+ *               (C) 1998-2004 by the Archimedes Project                       *
  *                   http://sourceforge.net/projects/archimedes                *
  *                                                                             *
  *             --------------------------------------------                    *
@@ -42,7 +42,7 @@
 
 	#include <glib.h>
 
-	#include <gettext.h>
+	//#include <gettext.h>
 
 	#if defined(__linux__) && defined(__alpha__)
 		#define _linuxalpha_
@@ -67,7 +67,7 @@
 		#include <unistd.h>
 	#endif
 
-	#if STDC_HEADERS || defined(USE_STDARG)
+	#if STDC_HEADERS || defined(HAVE_STDARG_H)
 		#if HAVE_STDARG_H
 			#include <stdarg.h>
 		#endif
@@ -601,6 +601,7 @@ typedef struct _mail_folder {
 	int color;      /* color (-1 - default)        */
 	int expire;     /* expire old messages (<= 0 don't expire) */
 	struct _mail_addr *From;/* default From: address */
+	struct _mail_addr *To;	/* default To: address */
 	long uid;       /* unique id */
 	void *cache;        /* cache info */
 	void *spec;     /* type-specific info */
@@ -911,8 +912,6 @@ typedef struct _mime_charset {
 	charset_encode encode;      /* Encode function     */
 	u_int flags;            /* special flags       */
 	#define CHARSET_FIXED   0x01        /* can not be deleted */
-	u_int font_style;       /* font to be used with charset */
-	u_int font_size;        /* font size of charset */
 } mime_charset;
 
 struct _mime_mailcap;
@@ -1114,32 +1113,27 @@ struct _mime_encoding *get_mime_encoding(struct _mail_msg *msg, struct _mime_msg
 /* returns NULL on error or if charset is unknown */
 struct _mime_charset *get_mime_charset(struct _mail_msg *msg, struct _mime_msg *mime);
 
-/* return code name of specific charset */
-/* returns -1 is charset does not exists */
-int get_charset_code(char *ch_name);
-
-/* returns font style of specific charset */
-/* returns -1 is charset does not exists */
-int get_charset_style(char *ch_name);
-
-/* returns font size of specific charset */
-/* returns -1 is charset does not exists */
-int get_charset_size(char *ch_name);
-
-/* sets font style of specific charset */
-/* returns -1 is charset does not exists */
-int set_charset_style(char *ch_name, int style);
-
-/* sets font size of specific charset */
-/* returns -1 is charset does not exists */
-int set_charset_size(char *ch_name, int size);
-
 /* returns > 0 if ch_name is an alias to already existing charset */
 /* and 0 if not. Returns -1 if specified charset does not exists */
 /* if it returns > 0 then the return value is index of main charset */
 /* + 1 */
 int is_charset_alias(char *ch_name);
 
+/* return the character set code given the name
+ * return -1 on failure
+ */
+int charset_code_from_name(char *ch_name);
+
+/* return the character set name given the code.
+ * return NULL on failure.
+ */
+const char *charset_name_from_code(int code);
+
+/* return the character set description, given the code.
+ * return NULL on failure.
+ */
+const char *charset_descr_from_code(int code);
+
 /* add new charset. ch_name - charset name, ch_descr - short description */
 /* if ch_code < 0 then new charset will be added , otherwise */
 /* an alias to existing charset with code ch_code will be added */
@@ -2241,13 +2235,17 @@ typedef struct _imap_src {
 	char password[IMAP_MAX_PASSWD_LEN + 1];      /* password */
 	char list[128];         /* hierarchies to list */
 	int flags;
-	#define ISRC_AUTOCON    0x01        /* autoconnect at startup */
-	#define ISRC_STOREPWD   0x02        /* store password */
-	#define ISRC_LOGSESSION 0x04        /* log session */
-	#define ISRC_TRASH  0x08        /* use trash */
-	#define ISRC_CACHE  0x10        /* cache between sessions */
-	#define ISRC_NOEXPUNGE  0x20        /* no autoexpunge */
-	#define ISRC_RETRIEVE   0x40        /* retrieve mail from this server */
+	#define ISRC_AUTOCON    0x001        /* autoconnect at startup */
+	#define ISRC_STOREPWD   0x002        /* store password */
+	#define ISRC_LOGSESSION 0x004        /* log session */
+	#define ISRC_TRASH  0x008        /* use trash */
+	#define ISRC_CACHE  0x010        /* cache between sessions */
+	#define ISRC_NOEXPUNGE  0x020        /* no autoexpunge */
+	#define ISRC_RETRIEVE   0x040        /* retrieve mail from this server */
+	#define ISRC_SSL     0x080 /* use SSL */
+	#define ISRC_SQUOTES	0x100	/* use single (') quotes to delimit
+									 * quoted strings */
+	
 	/* run-time variables */
 	int imapsock;           /* communication socket */
 	FILE *imap_in;          /* incoming data */
@@ -2309,7 +2307,7 @@ int load_smtp_acct(struct _smtp_account *, FILE *);
 /* saves smtp account configururation to a file */
 int save_smtp_acct(struct _smtp_account *, FILE *);
 
-
+void findreplace(string & haystack, string needle, string newtext);
 
 /* retrieves username and password from source account */
 int get_src_info( char * , char *, char *);
