@@ -1,10 +1,10 @@
-/* $Id: ldap.cpp,v 1.11 2002/11/22 05:25:44 cfreeze Exp $ */
+/* $Id: ldap.cpp,v 1.15 2004/01/02 03:54:01 fesnel Exp $ */
 /*******************************************************************************
  *   This program is part of a library used by the Archimedes email client     * 
  *                                                                             *
  *   Copyright : (C) 1995-1998 Gennady B. Sorokopud (gena@NetVision.net.il)    *
  *               (C) 1995 Ugen. J. S. Antsilevich (ugen@latte.worldbank.org)   *
- *               (C) 1998-2002 by the Archimedes Project                       *
+ *               (C) 1998-2004 by the Archimedes Project                       *
  *                   http://sourceforge.net/projects/archimedes                *
  *                                                                             *
  *             --------------------------------------------                    *
@@ -28,7 +28,7 @@
 
 #include "fldap.h"
 
-#ifdef HAVE_LDAP
+#ifdef WITH_LDAP
 
 LDAP * ld = NULL;
 int ldap_bound = 0;
@@ -147,27 +147,25 @@ char *make_filter(const char *str)
 
 int init_LDAP(void) 
 {
-	cerr << "init_LDAP called ";
+	//cerr << "init_LDAP called ";
 	if (ld == NULL) {
-		char hostport[255];
-		char * host;
-		char * port;
+        string sHostPort;
+        string sHost;
+        string sPort;
 
-		host = Config.getCString("LDAPserver", "");
-		if (host == NULL || *host == '\0') {
-			cerr << "init_LDAP bad host data" << endl;
-			return 0;
-		}
+		if(!Config.exist("LDAPserver"))
+            return 0;
 
-		port = Config.getCString("LDAPport", "");
+		sHost = Config.get("LDAPserver", "");
 
-		if (port != NULL && *port != '\0') {
-			snprintf(hostport, sizeof(hostport), "%s:%s", host, port);
-			host = hostport;
-		}
-		ld = ldap_init(host, LDAP_PORT);
+		if(Config.exist("LDAPport")) {
+		    sPort = Config.get("LDAPport", "");
+            sHost.append(":" + sPort);
+        }
+
+		ld = ldap_init(sHost.c_str(), LDAP_PORT);
 		if (ld == NULL) {
-			cerr << "ldap_init failure" << endl;
+			//cerr << "ldap_init failure" << endl;
 			display_msg(MSG_WARN, "LDAP", "Failure in ldap_init! Bad options?");
 			return -1;
 		}
@@ -175,11 +173,11 @@ int init_LDAP(void)
 
 	if (!ldap_bound) {
 		if (ldap_simple_bind_s(ld, NULL, NULL) != LDAP_SUCCESS) {
-			cerr << "ldap_simple_bind_s failure" << endl;
+			//cerr << "ldap_simple_bind_s failure" << endl;
 			return -1;
 		}
 		ldap_bound = 1;
-		cerr << "ldap_simple_bind_s: ldap is now bound" << endl;
+		//cerr << "ldap_simple_bind_s: ldap is now bound" << endl;
 	}
 	
 	return (ldap_bound);
@@ -195,7 +193,7 @@ void close_LDAP(void) {
 
 struct _mail_addr * find_ldap_expansion(char * name) {
 	struct _mail_addr * res = NULL;
-	char * base;
+    string sBase;
 	char *filter;
 	char *attributes[] = { "cn", "mail", NULL };
 	int searchRes;
@@ -205,47 +203,47 @@ struct _mail_addr * find_ldap_expansion(char * name) {
 	int initRes;
 	LDAPMessage * entry;
 
-	cerr << "find_ldap_expansion: searching for " << name << endl;
+	//cerr << "find_ldap_expansion: searching for " << name << endl;
 
 	initRes = init_LDAP();
 	if(initRes <= 0) {
 		if (initRes < 0) {
 			display_msg(MSG_WARN, "LDAP", "Can't initialise LDAP");
 		}
-		cerr << "find_ldap_expansion: init_LDAP returned bad result" << endl;
+		//cerr << "find_ldap_expansion: init_LDAP returned bad result" << endl;
 		return NULL;
 	}
 
-	base = Config.getCString("LDAPbase", "");
-	if(base == NULL) {
-		cerr << "find_ldap_expansion: LDAPbase was empty" << endl;
+    if(!Config.exist("LDAPbase")) {
+		//cerr << "find_ldap_expansion: LDAPbase was empty" << endl;
 		return NULL;
 	}
+
+	sBase = Config.get("LDAPbase", "");
 	
 	filter = make_filter(name);
 	if ( filter == NULL ) {
-		cerr << "find_ldap_expansion: unable to create filter" << endl;
+		//cerr << "find_ldap_expansion: unable to create filter" << endl;
 		return NULL;
 	}
 	
-	searchRes = ldap_search(ld, base, LDAP_SCOPE_SUBTREE, filter, attributes, 0);
+	searchRes = ldap_search(ld, sBase.c_str(), LDAP_SCOPE_SUBTREE, filter, attributes, 0);
 	free(filter);
 	if ( searchRes == -1 ) {
-		cerr << "find_ldap_expansion: ldap_search returned -1" << endl;
+		//cerr << "find_ldap_expansion: ldap_search returned -1" << endl;
 		return NULL;
 	}
 
-
 	noResults = 0;
 	maxResults = Config.getInt("LDAPmaxResults", DEFAULT_MAX_RESULTS);
 
-	cerr << "find_ldap_expansion: search returned " << searchRes 
-		<< " results. Only returning " << maxResults << "." <<  endl;
+	//cerr << "find_ldap_expansion: search returned " << searchRes 
+		//<< " results. Only returning " << maxResults << "." <<  endl;
 
 	while ((noResults++ < maxResults) &&
 	   ((rc = ldap_result(ld, LDAP_RES_ANY, 0, NULL, &msg)) == LDAP_RES_SEARCH_ENTRY)) {
 
-		cerr << "\tsearching result " << noResults << endl;
+		//cerr << "\tsearching result " << noResults << endl;
 
 		for (entry = ldap_first_entry(ld, msg);
 			entry != NULL;
@@ -254,7 +252,7 @@ struct _mail_addr * find_ldap_expansion(char * name) {
 			BerElement * ber;
 			char * attrib;
 
-			cerr << "\t\tsearching entry " << noResults << endl;
+			//cerr << "\t\tsearching entry " << noResults << endl;
 
 			ma = (struct _mail_addr *)malloc(sizeof(struct _mail_addr));
 			if (ma == NULL) {
@@ -270,7 +268,7 @@ struct _mail_addr * find_ldap_expansion(char * name) {
 				attrib = ldap_next_attribute(ld, entry, ber)) {
 				char ** values;
 
-				cerr << "\t\t\tsearching attrib " << noResults << endl;
+				//cerr << "\t\t\tsearching attrib " << noResults << endl;
 
 				values = ldap_get_values(ld, entry, attrib);
 				if ( values != NULL) {
@@ -291,7 +289,7 @@ struct _mail_addr * find_ldap_expansion(char * name) {
 		   	* or other missing will be problematic later on.
 		   	*/
 		  	if ( ma->name == NULL || ma->addr == NULL ) {
-				cerr << "find_ldap_expansion: ignoring problematic result" << endl;
+				//cerr << "find_ldap_expansion: ignoring problematic result" << endl;
 				free(ma);
 				continue;
 		  	}
@@ -302,7 +300,7 @@ struct _mail_addr * find_ldap_expansion(char * name) {
 
 			ma->next_addr = res;
 			res = ma;
-			cerr << "find_ldap_expansion: Result found!" << endl;
+			//cerr << "find_ldap_expansion: Result found!" << endl;
 		}
 
 		ldap_msgfree(msg);
@@ -318,4 +316,4 @@ struct _mail_addr * find_ldap_expansion(char * name) {
 	return res;
 }
 
-#endif /* HAVE_LDAP */
+#endif /* WITH_LDAP */
