@@ -1,10 +1,10 @@
-/* $Id: mbox.cpp,v 1.18 2002/12/30 06:56:53 fesnel Exp $ */
+/* $Id: mbox.cpp,v 1.25 2004/01/02 03:54:01 fesnel Exp $ */
 /*******************************************************************************
  *   This program is part of a library used by the Archimedes email client     * 
  *                                                                             *
  *   Copyright : (C) 1995-1998 Gennady B. Sorokopud (gena@NetVision.net.il)    *
  *               (C) 1995 Ugen. J. S. Antsilevich (ugen@latte.worldbank.org)   *
- *               (C) 1998-2002 by the Archimedes Project                       *
+ *               (C) 1998-2004 by the Archimedes Project                       *
  *                   http://sourceforge.net/projects/archimedes                *
  *                                                                             *
  *             --------------------------------------------                    *
@@ -251,8 +251,8 @@ int lockfolder(struct _mail_folder *folder) {
 
 		if(flock(fileno(ffd), LOCK_EX | LOCK_NB) == -1) {
 			display_msg(MSG_WARN, "LOCK",
-						"Can not lock folder (flock(%i) failed)\n%s",ffd,
-						folder->fold_path);
+				"Can not lock folder (flock(%i) failed)\n%s",
+				fileno(ffd), folder->fold_path);
 			return -1;
 		}
 #endif
@@ -319,7 +319,7 @@ int lockfolder(struct _mail_folder *folder) {
 			return -1;
 		}
 #else
-	#ifdef HAVE_LOCKF
+#ifdef HAVE_LOCKF
 		if(fseek(ffd, 0, SEEK_SET) == -1) {
 			display_msg(MSG_WARN, "UNLOCK", "Can not seek");
 			return -1;
@@ -331,7 +331,7 @@ int lockfolder(struct _mail_folder *folder) {
 				return -1;
 			}
 		}
-	#endif
+#endif
 #endif
 	}
 
@@ -379,7 +379,7 @@ int unlockfolder(struct _mail_folder *folder) {
 			return -1;
 		}
 #else
-	#ifdef HAVE_LOCKF
+#ifdef HAVE_LOCKF
 		if(fseek(ffd, 0, SEEK_SET) == -1) {
 			display_msg(MSG_WARN, "UNLOCK", "Can not seek");
 			return -1;
@@ -391,7 +391,7 @@ int unlockfolder(struct _mail_folder *folder) {
 				return -1;
 			}
 		}
-	#endif
+#endif
 #endif
 	}
 
@@ -2120,15 +2120,14 @@ int get_mbox_message_text(struct _mail_msg *msg, struct _mime_msg *mime) {
 	mboxmsg = msg->msg_body;
 	mboxmsglen = mlen;
 
-#ifdef HAVE_MADVISE
-	#ifdef  MADV_SEQUENTIAL
+#if defined(HAVE_MADVISE) && defined(MADV_SEQUENTIAL)
 	madvise(msg->msg_body, mlen, MADV_SEQUENTIAL);
-	#endif
 #endif
 
 	msg->msg_body_len = msg->msg_len;
 	msg->msg_body += lofft;
 	if((ptr = memchr(msg->msg_body, '\n', msg->msg_body_len)) != NULL) {
+        msg->msg_body_len -= (char*)ptr - msg->msg_body + 1;
 		msg->msg_body = (char *) ptr;
 		msg->msg_body++;
 	}
@@ -3040,7 +3039,7 @@ void update_clen(struct _mail_msg *msg) {
 
 	delete_all_fields(msg, MIME_C_LENGTH);
 	if(clen <= 0) {
-		display_msg(MSG_WARN, "FOLDER", "Invalid %s, ignoring",
+		display_msg(MSG_LOG, "FOLDER", "Invalid %s, ignoring",
 					MIME_C_LENGTH);
 		return;
 	}
@@ -3127,7 +3126,7 @@ long mbox_inc_mail(struct _retrieve_src *source, long *notify) {
 			replace_field(msg, SOURCE_FIELD, source->name);
 			msg->header->rcv_time = time(NULL);
 
-#ifdef FACES
+#ifdef WITH_FACES
 			update_faces(msg);
 #endif
 
