@@ -1,10 +1,10 @@
-/* $Id: nntp.cpp,v 1.9 2003/01/05 06:50:12 fesnel Exp $ */
+/* $Id: nntp.cpp,v 1.13 2004/01/02 03:54:01 fesnel Exp $ */
 /*******************************************************************************
  *   This program is part of a library used by the Archimedes email client     * 
  *                                                                             *
  *   Copyright : (C) 1995-1998 Gennady B. Sorokopud (gena@NetVision.net.il)    *
  *               (C) 1995 Ugen. J. S. Antsilevich (ugen@latte.worldbank.org)   *
- *               (C) 1998-2002 by the Archimedes Project                       *
+ *               (C) 1998-2004 by the Archimedes Project                       *
  *                   http://sourceforge.net/projects/archimedes                *
  *                                                                             *
  *             --------------------------------------------                    *
@@ -41,7 +41,7 @@ FILE *nntp_in = NULL;
 FILE *nntp_out = NULL;
 
 
-#if STDC_HEADERS || defined(USE_STDARG)
+#if STDC_HEADERS || defined(HAVE_STDARG_H)
 int nntp_command(char *fmt, ...)
 #else
 int nntp_command(char *fmt, va_dcl
@@ -52,7 +52,7 @@ int nntp_command(char *fmt, va_dcl
 	char buf[255];
 	va_list ap;
 
-#if STDC_HEADERS || defined(USE_STDARG)
+#if STDC_HEADERS || defined(HAVE_STDARG_H)
 	va_start(ap, fmt);
 #else
 	va_start(ap);
@@ -116,10 +116,11 @@ int nntp_init() {
 		return -1;
 	}
 
-	strcpy(buf, Config.getCString("nntphost", "news"));
+	strcpy(buf, Config.get("nntphost", "news").c_str());
 	nntpsock =
-	ConMan.host_connect(buf, Config.getCString("nntport", "119"),
-				 NULL); if(nntpsock == -1)
+	ConMan.host_connect(buf, const_cast<char *>(Config.get("nntport", "119").c_str()), NULL); 
+    
+    if(nntpsock == -1)
 		return -1;
 
 	if((nntp_in = fdopen(nntpsock, "r+")) == NULL) {
@@ -131,10 +132,9 @@ int nntp_init() {
 	nntp_out = nntp_in;
 
 	if(Config.getInt("nntpauth", 0)) {
-		if((strlen(Config.getCString("nntpasswd", "")) < 1)
-		   && (Config.getInt("nntpstorpwd", 0) == 0))
+		if(Config.exist("nntpasswd") && (Config.getInt("nntpstorpwd", 0) == 0))
 			nntp_account();
-		if(strlen(Config.getCString("nntpuser", user_n)))
+		if(Config.exist("nntpuser"))
 			authusr = 1;
 		authpass = 1;
 	}
@@ -160,11 +160,11 @@ int nntp_init() {
 
 	nntp_user:
 	if(authusr) {
-		if(strlen(Config.getCString("nntpuser", user_n)) == 0)
+		if(!Config.exist("nntpuser"))
 			nntp_account();
 		switch(nntp_command
 			   ("AUTHINFO USER %s",
-				Config.getCString("nntpuser", user_n))) {
+				Config.get("nntpuser", user_n).c_str())) {
 			case 381:
 				authpass = 1;
 				break;
@@ -182,11 +182,9 @@ int nntp_init() {
 	}
 
 	if(authpass) {
-		if(strlen(Config.getCString("nntpasswd", "")) == 0)
+		if(Config.exist("nntpasswd"))
 			nntp_account();
-		switch(nntp_command
-			   ("AUTHINFO PASS %s",
-				Config.getCString("nntpasswd", ""))) {
+		switch(nntp_command("AUTHINFO PASS %s", Config.get("nntpasswd", "").c_str())) {
 			case 281:
 				break;
 
@@ -198,9 +196,7 @@ int nntp_init() {
 
 			default:
 				nntp_account();
-				if(nntp_command
-				   ("AUTHINFO PASS %s",
-					Config.getCString("nntpasswd", "")) != 281) {
+				if(nntp_command ("AUTHINFO PASS %s", Config.get("nntpasswd", "").c_str()) != 281) {
 					display_msg(MSG_WARN, "nntp", "%-.127s", response);
 					nntp_close();
 					return -1;
