@@ -1,10 +1,10 @@
-/* $Id: pgp.cpp,v 1.18 2002/11/12 01:25:59 fesnel Exp $ */
+/* $Id: pgp.cpp,v 1.22 2004/01/02 03:54:01 fesnel Exp $ */
 /*******************************************************************************
  *   This program is part of a library used by the Archimedes email client     * 
  *                                                                             *
  *   Copyright : (C) 1995-1998 Gennady B. Sorokopud (gena@NetVision.net.il)    *
  *               (C) 1995 Ugen. J. S. Antsilevich (ugen@latte.worldbank.org)   *
- *               (C) 1998-2002 by the Archimedes Project                       *
+ *               (C) 1998-2004 by the Archimedes Project                       *
  *                   http://sourceforge.net/projects/archimedes                *
  *                                                                             *
  *             --------------------------------------------                    *
@@ -204,8 +204,8 @@ static char *get_pgp500_command_line(int mode, struct pgpargs *pargs,
 
 	if(!(t & NORMAL) && (t & KEYRING))
 		snprintf(pubring, sizeof(pubring), "+pubring=%s",
-				 Config.getCString("pgpkeyring", ""));
-	pgpprg = strdup(Config.getCString("pgp", _PATH_PGP));
+				 Config.get("pgpkeyring", "").c_str());
+	pgpprg = strdup(Config.get("pgp", _PATH_PGP).c_str());
 	if(pargs && (pargs->userid == NULL)) {
 		if((mode & (SIGN | SIGNFL)) && pargs->msg
 		   && pargs->msg->header->From) {
@@ -220,7 +220,7 @@ static char *get_pgp500_command_line(int mode, struct pgpargs *pargs,
 			  pargs->userid = addr->pgpid;
 		}
 		if(pargs->userid == NULL)
-			pargs->userid = Config.getCString("pgpuser", user_n);
+			pargs->userid = const_cast<char *>(Config.get("pgpuser", user_n).c_str());
 	}
 	if((mode & ENCODE) && (mode & SIGN))
 		snprintf(args, sizeof(args),
@@ -267,14 +267,14 @@ static char *get_pgp651_command_line(int mode, struct pgpargs *pgpargs,
 									 char *inbuf, int t) {
 	char args[1024];
 	char pubring[2048] = "";
-	const char pgpparm[] = "+language=en +verbose=1 +clearsig=on";
+	const char pgpparm[] = "+language=en +verbose=1 +force +clearsig=on";
 	char *pgpprg;
 	struct _mail_addr *addr, *addr1;
 
 	if(!(t & NORMAL) && (t & KEYRING))
 		snprintf(pubring, sizeof(pubring), "+pubring=%s",
-				 Config.getCString("pgpkeyring", ""));
-	pgpprg = strdup(Config.getCString("pgp", _PATH_PGP));
+				 Config.get("pgpkeyring", "").c_str());
+	pgpprg = strdup(Config.get("pgp", _PATH_PGP).c_str());
 	if(pgpargs && (pgpargs->userid == NULL)) {
 		if((mode & (SIGN | SIGNFL)) && pgpargs->msg
 		   && pgpargs->msg->header->From) {
@@ -289,8 +289,7 @@ static char *get_pgp651_command_line(int mode, struct pgpargs *pgpargs,
 			  pgpargs->userid = addr->pgpid;
 		}
 		if(pgpargs->userid == NULL)
-			pgpargs->userid =
-			Config.getCString("pgpuser", user_n);
+			pgpargs->userid = const_cast<char*>(Config.get("pgpuser", user_n).c_str());
 	}
 	if((mode & ENCODE) && (mode & SIGN))
 		snprintf(args, sizeof(args), "%s %s +batchmode -fates %s -u %s",
@@ -342,8 +341,8 @@ static char *get_pgp263_command_line(int mode, struct pgpargs *pgpargs,
 
 	if(!(t & NORMAL) && (t & KEYRING))
 		snprintf(pubring, sizeof(pubring), "+pubring=%s",
-				 Config.getCString("pgpkeyring", ""));
-	pgpprg = strdup(Config.getCString("pgp", _PATH_PGP));
+				 Config.get("pgpkeyring", "").c_str());
+	pgpprg = strdup(Config.get("pgp", _PATH_PGP).c_str());
 	if(pgpargs && (pgpargs->userid == NULL)) {
 		if((mode & (SIGN | SIGNFL)) && pgpargs->msg
 		   && pgpargs->msg->header->From) {
@@ -358,8 +357,7 @@ static char *get_pgp263_command_line(int mode, struct pgpargs *pgpargs,
 				pgpargs->userid = addr->pgpid;
 		}
 		if(pgpargs->userid == NULL)
-			pgpargs->userid =
-			Config.getCString("pgpuser", user_n);
+			pgpargs->userid = const_cast<char *>(Config.get("pgpuser", user_n).c_str());
 	}
 	if((mode & ENCODE) && (mode & SIGN))
 		snprintf(args, sizeof(args), "%s %s +batchmode -fate %s -su %s ",
@@ -414,8 +412,8 @@ static char *get_gpg_command_line(int mode, struct pgpargs *pgpargs,
 
 	if(!(t & NORMAL) && (t & KEYRING))
 		snprintf(pubring, sizeof(pubring), "--keyring=%s",
-				 Config.getCString("pgpkeyring", ""));
-	pgpprg = strdup(Config.getCString("pgp", _PATH_PGP));
+				 Config.get("pgpkeyring", "").c_str());
+	pgpprg = strdup(Config.get("pgp", _PATH_PGP).c_str());
 	if(pgpargs && (pgpargs->userid == NULL)) {
 		if((mode & (SIGN | SIGNFL)) && pgpargs->msg
 		   && pgpargs->msg->header->From) {
@@ -430,8 +428,7 @@ static char *get_gpg_command_line(int mode, struct pgpargs *pgpargs,
 			  pgpargs->userid = addr->pgpid;
 		}
 		if(pgpargs->userid == NULL)
-			pgpargs->userid =
-			Config.getCString("pgpuser", user_n);
+			pgpargs->userid = const_cast<char *>(Config.get("pgpuser", user_n).c_str());
 	}
 	/* sign & encode needs passphrase */
 	if((mode & ENCODE) && (mode & SIGN))
@@ -508,7 +505,7 @@ int pgp_action(char *inbuf, int mode, struct pgpargs *pgpargs) {
 
 		if(!(t & (NORMAL | KEYRING)) && (t & HTTP)) {
 			if(pgp_fetch_key_from_http
-			   (Config.getCString("pgpkeyserver", "pgp5.ai.mit.edu"),
+			   (const_cast<char *>(Config.get("pgpkeyserver", "wwwkeys.pgp.net").c_str()),
 				keyid) == -1) {    /* if we can not find signature during decode - still procede */
 				if(mode & DECODE)
 					break;
