@@ -1,10 +1,10 @@
-/* $Id: pop.cpp,v 1.22 2002/12/30 18:35:17 fesnel Exp $ */
+/* $Id: pop.cpp,v 1.31.2.1 2004/01/16 04:43:18 fesnel Exp $ */
 /*******************************************************************************
  *   This program is part of a library used by the Archimedes email client     * 
  *                                                                             *
  *   Copyright : (C) 1995-1998 Gennady B. Sorokopud (gena@NetVision.net.il)    *
  *               (C) 1995 Ugen. J. S. Antsilevich (ugen@latte.worldbank.org)   *
- *               (C) 1998-2002 by the Archimedes Project                       *
+ *               (C) 1998-2004 by the Archimedes Project                       *
  *                   http://sourceforge.net/projects/archimedes                *
  *                                                                             *
  *             --------------------------------------------                    *
@@ -33,7 +33,7 @@
 #include <connectionManager.h>
 #include "md5.h"
 
-#ifdef USE_THREADS
+#ifdef WITH_THREADS
 	#include <pthread.h>
 #endif
 
@@ -95,7 +95,7 @@ int get_ipc_sock(struct sockaddr_in *sin) {
 }
 
 
-#ifdef USE_THREADS
+#ifdef WITH_THREADS
 extern "C" void gethostbystring_failed(int i) {
 	pthread_exit(NULL);
 }
@@ -114,7 +114,7 @@ extern "C" void *gethostbystring_thread(void *s) {
 
 extern "C" struct hostent *gethostbystring(char *s) {
 
-#ifdef USE_THREADS
+#if 0 //WITH_THREADS
 	struct hostent **hpp;
 	pthread_t resolv_thread;
 #endif
@@ -129,7 +129,7 @@ extern "C" struct hostent *gethostbystring(char *s) {
 #endif
 
 
-#ifdef USE_THREADS
+#if 0 //WITH_THREADS
 	pthread_create(&resolv_thread, NULL, gethostbystring_thread,
 				   (void *) s);
 	pthread_join(resolv_thread, (void **) hpp);
@@ -152,7 +152,7 @@ extern "C" struct hostent *gethostbystring(char *s) {
 			return hp;
 		}
 	}
-#ifdef USE_THREADS
+#if 0 //WITH_THREADS
 	return *hpp;
 #else
 	return hp;
@@ -528,7 +528,7 @@ int putline(char *s, FILE * iop) {
 
 	return 0;
 }
-#if STDC_HEADERS || defined(USE_STDARG)
+#if STDC_HEADERS || defined(HAVE_STDARG_H)
 char *pop_command(struct _pop_src *pop, char *fmt, ...)
 #else
 char *pop_command(struct _pop_src *pop, char *fmt, va_dcl
@@ -538,7 +538,11 @@ char *pop_command(struct _pop_src *pop, char *fmt, va_dcl
 	va_list ap;
 	static char commandln[514];
 
-#if STDC_HEADERS || defined(USE_STDARG)
+	/* If the pop socket is closed, don't even try sending. */
+	if (pop->pop_out == NULL)
+		return NULL;
+
+#if STDC_HEADERS || defined(HAVE_STDARG_H)
 	va_start(ap, fmt);
 #else
 	va_start(ap);
@@ -546,6 +550,8 @@ char *pop_command(struct _pop_src *pop, char *fmt, va_dcl
 
 	vsnprintf(commandln, sizeof(commandln), fmt, ap);
 
+	va_end(ap);
+
 	if(pop->flags & PSRC_LOGSESSION) {
 		if(strncasecmp(commandln, "pass ", 5))
 			display_msg(MSG_LOG, "pop", "-> %-.127s", commandln);
@@ -581,7 +587,8 @@ char *pop_command(struct _pop_src *pop, char *fmt, va_dcl
 void pop_close(struct _pop_src *pop) {
 	struct _uidl *ucache;
 
-	ConMan.del_cinfo(pop->popsock);
+	if (pop->popsock != -1)
+		ConMan.del_cinfo(pop->popsock);
 
 	while(pop->uidlcache) {
 		ucache = pop->uidlcache;
@@ -1558,7 +1565,7 @@ long pop_inc(struct _retrieve_src *source, long *notify) {
 		replace_field(msg, SOURCE_FIELD, source->name);
 		msg->header->rcv_time = time(NULL);
 
-#ifdef FACES
+#ifdef WITH_FACES
 		update_faces(msg);
 #endif
 
