@@ -1,10 +1,10 @@
-/* $Id: rules.cpp,v 1.5 2002/12/30 18:38:53 fesnel Exp $ */
+/* $Id: rules.cpp,v 1.8 2004/01/02 03:54:01 fesnel Exp $ */
 /*******************************************************************************
  *   This program is part of a library used by the Archimedes email client     * 
  *                                                                             *
  *   Copyright : (C) 1995-1998 Gennady B. Sorokopud (gena@NetVision.net.il)    *
  *               (C) 1995 Ugen. J. S. Antsilevich (ugen@latte.worldbank.org)   *
- *               (C) 1998-2002 by the Archimedes Project                       *
+ *               (C) 1998-2004 by the Archimedes Project                       *
  *                   http://sourceforge.net/projects/archimedes                *
  *                                                                             *
  *             --------------------------------------------                    *
@@ -264,7 +264,7 @@ void init_rule(struct _xf_rule *rule) {
 int match_rule(struct _mail_msg *msg, struct _xf_rule *rule) {
 	struct _mail_addr *addr;
 	int fr;
-	char *p;
+	char *p, c;
 
 	if(!msg || !rule) {
 		return 0;
@@ -297,18 +297,42 @@ int match_rule(struct _mail_msg *msg, struct _xf_rule *rule) {
 		return 0;
 	}
 
+	/* XXX: There's a flaw in the design of the mmaping code that
+	 * if the length of the message body is a multiple of the page
+	 * length, then the message body might not be
+	 * null-terminated. This is because mmap won't mmap more than
+	 * the file length. Therefore, the body field has to be
+	 * truncated so that the regexec/strcasestr doesn't run off
+	 * the end of the string. The last character is restored after
+	 * the search is done.
+	 *
+	 * We hope that removing the last character from the mail
+	 * doesn't affect what the user was searching for.
+	 */
+	c = -1;
+	if (strncasecmp(rule->fmatch, "Body", 4) == 0 && fr == 1) {
+	    c = msg->msg_body[msg->msg_body_len - 1];
+	    msg->msg_body[msg->msg_body_len - 1] = '\0';
+	}
+
 #ifdef HAVE_REGCOMP
 	if(regexec(&rule->rx, p, 0, 0, 0) == 0) {
+		if (c != -1)
+			msg->msg_body[msg->msg_body_len - 1] = c;
 		free_field_content(msg, p, fr);
 		return 1;
 	}
 #else
 	if(strcasestr(p, rule->tmatch, rule->flags & CASE_I)) {
+		if (c != -1)
+			msg->msg_body[msg->msg_body_len - 1] = c;
 		free_field_content(msg, p, fr);
 		return 1;
 	}
 #endif
 
+	if (c != -1)
+		msg->msg_body[msg->msg_body_len - 1] = c;
 	free_field_content(msg, p, fr);
 
 	return 0;
