@@ -1,10 +1,10 @@
-/* $Id: smtp.cpp,v 1.29 2002/12/30 18:49:21 fesnel Exp $ */
+/* $Id: smtp.cpp,v 1.38 2004/01/02 03:54:01 fesnel Exp $ */
 /*******************************************************************************
  *   This program is part of a library used by the Archimedes email client     * 
  *                                                                             *
  *   Copyright : (C) 1995-1998 Gennady B. Sorokopud (gena@NetVision.net.il)    *
  *               (C) 1995 Ugen. J. S. Antsilevich (ugen@latte.worldbank.org)   *
- *               (C) 1998-2002 by the Archimedes Project                       *
+ *               (C) 1998-2004 by the Archimedes Project                       *
  *                   http://sourceforge.net/projects/archimedes                *
  *                                                                             *
  *             --------------------------------------------                    *
@@ -37,7 +37,7 @@
 extern gPasswd Passwd;
 #endif
 
-#ifdef USE_THREADS
+#ifdef WITH_THREADS
 #include <pthread.h>
 extern pthread_mutex_t send_mutex;
 #endif
@@ -45,7 +45,6 @@ extern pthread_mutex_t send_mutex;
 extern cfgfile Config;
 extern class connectionManager ConMan;
 
-extern void auth_smtp_account(char *, char *, char * );
 void get_smtp_host_info (char * , struct _smtp_account * *);
 
 static struct _smtp_account *smtp_account; 
@@ -61,7 +60,7 @@ static int smtpcap = 0;
 FILE *smtp_in = NULL;
 FILE *smtp_out = NULL;
 
-#if STDC_HEADERS || defined(USE_STDARG)
+#if STDC_HEADERS || defined(HAVE_STDARG_H)
 int smtp_command(char *fmt, ...)
 #else
 int smtp_command(char *fmt, va_dcl va_list)
@@ -71,7 +70,7 @@ int smtp_command(char *fmt, va_dcl va_list)
 	char buf[255];
 	va_list ap;
 
-#if STDC_HEADERS || defined(USE_STDARG)
+#if STDC_HEADERS || defined(HAVE_STDARG_H)
 	va_start(ap, fmt);
 #else
 	va_start(ap);
@@ -102,10 +101,12 @@ int smtp_command(char *fmt, va_dcl va_list)
 		if (ehlo) {
 			if (response[3] != '-')
 				break;
-			sscanf(response, "%d-%s", &res, buf);
+
+			res = atoi(response);
 			if (res != 250)
 				continue;
 
+			snprintf(buf, sizeof(buf), "%s", response + 4);
 			if (!strncasecmp(buf, "DSN", 3))
 				smtpcap |= SMTP_DSN;
 
@@ -169,7 +170,7 @@ int smtp_init(struct _mail_msg *msg)
 		return -1;
 	}
 
-	strncpy(bfr, Config.getCString("smtphost", "127.0.0.1"), sizeof(bfr));
+	strncpy(bfr, Config.get("smtphost", "127.0.0.1").c_str(), sizeof(bfr));
 	while((ptr=strchr(buf,','))!=0L)
 	{
 		*ptr++=0;
@@ -186,7 +187,7 @@ int smtp_init(struct _mail_msg *msg)
 	}
 
 	smtp_host = buf;
-	smtp_port = Config.getCString("smtport",DEFAULT_SMTP_PORT);
+	smtp_port = const_cast<char *>(Config.get("smtport",DEFAULT_SMTP_PORT).c_str());
 	if (!smtp_port)
 		smtp_port = default_smtp_port;
 
@@ -210,13 +211,6 @@ int smtp_init(struct _mail_msg *msg)
 		smtp_host = smtp_account->hostname ;
 		if (smtp_account->service)
 			smtp_port = smtp_account->service;
-		if (auth_required && !( smtp_account->flags &  SMTP_AUTH )){
-			display_msg(MSG_WARN, "smtp", 
-			    "authentication required, but not enabled for smtp account\n%s",
-			    smtp_account->name);
-			smtp_close();
-			return -1;
-		}
 	}	
 
 	/* 
@@ -271,23 +265,18 @@ int smtp_init(struct _mail_msg *msg)
 		smtpcap |= SMTP_ESMTP;
 
 	}
-	/* do smpt RFC2554 or "AUTH=LOGIN" authentication if necessary */
-	if (auth_required) {
-		if (smtp_authenticate(smtp_host,smtp_port,smtp_auth_list)){
-			display_msg(MSG_WARN, "smtp", "%-.127s", response);
-			if (smtp_account) {
-				/* try again, prompting user for username+password */
-				char *p = smtp_account->username;
-				*p = '\0';
-				if (!smtp_authenticate(smtp_host,smtp_port,smtp_auth_list))
-					return 0;
-				display_msg(MSG_WARN, "smtp", "%-.127s", response);
+	/* do smpt RFC2554 or "AUTH=LOGIN" authentication if necessary,
+	 and if smtp_account is configured for this */
+	if(smtp_account) {
+		if (auth_required && (smtp_account->flags & SMTP_AUTH )) {
+			if (smtp_authenticate(smtp_host,smtp_auth_list)){
+				display_msg(MSG_WARN, "smtp",
+					    "required authentication failed"
+					    " (smtp account \"%s\")",
+					    smtp_account->name);
 			}
-			smtp_close();
-			return -1;
 		}
 	}
-
 	return 0;
 }
 
@@ -314,60 +303,78 @@ void *smtp_send_message(void *arg)
 	struct _mail_addr *addr;
 	struct _head_field *hf;
 	time_t lt;
-	int usedsn = 0;
+	int retval, usedsn = 0;
 	char id[32], buf[100], *envid;
 
-#ifdef USE_THREADS
+#ifdef WITH_THREADS
 	if (pthread_mutex_trylock(&send_mutex) == EBUSY) {
 		display_msg(MSG_LOG,NULL, "Send Already In Progress, Must Wait Till It Completes");
 		return NULL;        //A Send Thread is already in progress
 	}
 #endif
-
+	
 	lt = time(NULL);
 
 	switch (smtp_init(msg)) {
-		case -1:
-			send_message_finalizer(msg, -1);
-			return NULL;
-
-		case -2:
-			send_message_finalizer(msg, -2);
+	case -1:
+		send_message_finalizer(msg, -1);
+		return NULL;
+		
+	case -2:
+		send_message_finalizer(msg, -2);
 			return NULL;
 	}
-
+	
 	if ((smtpcap & SMTP_ESMTP) && (smtpcap & SMTP_DSN) &&
-		((hf = find_field(msg, "Return-Receipt-To")) != NULL) &&
+	    ((hf = find_field(msg, "Return-Receipt-To")) != NULL) &&
 		Config.getInt("smtpdsn", 0)) {
-			usedsn = 1;
-			delete_all_fields(msg, "X-DSN-Envid");
-			delete_all_fields(msg, "Return-Receipt-To");
+		usedsn = 1;
+		delete_all_fields(msg, "X-DSN-Envid");
+		delete_all_fields(msg, "Return-Receipt-To");
 	}
-
+	
 	if (usedsn) {
 		if ((hf = find_field(msg, "Message-ID")) == NULL) {
-				strftime(id, 31, "%Y%m%d%H%M%S", localtime(&lt));
-				snprintf(buf, sizeof(buf), "<XFMail-DSN.%s.%s>", id,
-			 	msg->header->From->addr);
-				add_field(msg, "Message-ID", buf);
-				envid = buf;
+			strftime(id, 31, "%Y%m%d%H%M%S", localtime(&lt));
+			snprintf(buf, sizeof(buf), "<XFMail-DSN.%s.%s>", id,
+				 msg->header->From->addr);
+			add_field(msg, "Message-ID", buf);
+			envid = buf;
 		}
 		envid = hf->f_line;
-
-		if (smtp_command("MAIL FROM: <%s> RET=HDRS ENVID=%s",
-			 msg->header->From->addr, envid) != 250) {
-				display_msg(MSG_WARN, "smtp", "%-.127s", response);
-				smtp_end();
-				send_message_finalizer(msg, -1);
-				return NULL;
-		}
+		retval = smtp_command("MAIL FROM: <%s> RET=HDRS ENVID=%s",
+				      msg->header->From->addr, envid);
 	} else {
-		if (smtp_command("MAIL FROM: <%s>", msg->header->From->addr) != 250) {
-			display_msg(MSG_WARN, "smtp", "%-.127s", response);
-			smtp_end();
-			send_message_finalizer(msg, -1);
-			return NULL;
+		retval = smtp_command("MAIL FROM: <%s>", msg->header->From->addr);
+	}
+
+	if(retval == 530) {  /* server requires smtp authentication */
+		int retry = 0;
+		while (retry < 3) {
+			retry ++;
+			retval = smtp_authenticate(true_host,smtp_auth_list);
+			if (retval != 535 || retry == 3)
+				break;
+			display_msg(MSG_WARN, "smtp",
+				    "authentication attempt %d"
+				    " failed (3 allowed)",
+				    retry);
 		}
+		if (!retval)  /* successful authentication */
+			if (usedsn) {
+				retval = smtp_command("MAIL FROM: <%s> RET=HDRS ENVID=%s",
+						      msg->header->From->addr, envid);
+			} else {
+				retval = smtp_command("MAIL FROM: <%s>",
+						      msg->header->From->addr);
+			}
+	}
+
+	if (retval != 250) {
+		display_msg(MSG_WARN, "smtp", "%-.127s", response);
+		smtp_end();
+		send_message_finalizer(msg, -1);
+		return NULL;
 	}
 
 	addr = msg->header->To;
