@@ -1,4 +1,4 @@
-/* $Id: smtp_auth.cpp,v 1.10 2001/12/25 17:27:27 fesnel Exp $ */
+/* $Id: smtp_auth.cpp,v 1.11 2003/04/21 01:08:15 duncan_haldane Exp $ */
 /*******************************************************************************
  *   This program is part of a library used by the Archimedes email client     * 
  *                                                                             *
@@ -43,8 +43,7 @@ char smtp_username[MAX_AUTH_WORD_LEN+1];
   return;
 }
 
-int smtp_authenticate( char * smtp_hostname, char * smtp_port, 
-			   char * server_auth_list )
+int smtp_authenticate( char * smtp_hostname, char * server_auth_list )
 {  
   /*
 	RFC2554 "SMTP Service Extension for Authentication" dialog.
@@ -172,7 +171,7 @@ int smtp_authenticate( char * smtp_hostname, char * smtp_port,
 		
 		  case 535:   /* client authentication data rejected by server */
 		erase_password(smtp_password,sizeof(smtp_password));
-		return -1;
+		return 535;
 		break;
 		
 		  case 501:  /* server cannot decode "client_to_server" string */
@@ -217,7 +216,7 @@ int smtp_authenticate( char * smtp_hostname, char * smtp_port,
 		  
 		case 535:   /* authentication failed */
 		  erase_password(smtp_password,sizeof(smtp_password));
-		  return -1;
+		  return 535;
 		  break;
 		  
 		case 538:   /* encrypted conection required */
