@@ -1,4 +1,4 @@
-/* $Id: smtp_auth.h,v 1.8 2001/11/18 00:23:55 fesnel Exp $ */
+/* $Id: smtp_auth.h,v 1.9 2003/04/21 01:08:15 duncan_haldane Exp $ */
 /*******************************************************************************
  *   This program is part of a library used by the Archimedes email client     * 
  *                                                                             *
@@ -40,7 +40,7 @@ void  ask_smtp_password( char * , char * , char * , int );
   char * is a pointer to the AUTH EHLO keyword list  sent by
   the server.
 */
-int smtp_authenticate( char * , char *, char *);
+int smtp_authenticate( char * , char *);
 
 
 #ifdef _SMTP_AUTH_C_
