@@ -1,4 +1,4 @@
-/* $Id: addrbook.cpp,v 1.7 2002/12/19 05:09:03 fesnel Exp $ */
+/* $Id: addrbook.cpp,v 1.9 2003/07/19 00:12:37 fesnel Exp $ */
 /*******************************************************************************
  *   This program is part of the XFMail email client.                          *
  *                                                                             *
@@ -343,7 +343,7 @@ struct _mail_addr *addr_book(int *addr_type, addr_dbl_cb callback,
 	Config.setFlags("abookgeom", CF_NOTCHANGED);
 	w = 700;
 	h = 280;
-	sscanf(Config.getCString("abookgeom", ""), "%d %d", &w, &h);
+	sscanf(Config.get("abookgeom", "").c_str(), "%d %d", &w, &h);
 	if(Config.getInt("wplace", 1))
 		fl_set_form_geometry(addr_book_obj->Address_Book,
 							 (abookx > 0)
@@ -939,22 +939,22 @@ int mod_addr(struct _mail_addr *oldadr, int *type) {
 		fl_set_input(amod_obj->AMOD_PGP_Input, oldadr->pgpid);
 	if(ftype >= 0) {
 		fl_set_object_lstyle(amod_obj->AMOD_Input,
-							 supp_charsets[ftype].font_style);
+			charset_style_from_code(supp_charsets[ftype].charset_code));
 		fl_set_object_lsize(amod_obj->AMOD_Input,
-							supp_charsets[ftype].font_size);
+			charset_size_from_code(supp_charsets[ftype].charset_code));
 		fl_set_object_lstyle(amod_obj->AMOD_PGP_Input,
-							 supp_charsets[ftype].font_style);
+			charset_style_from_code(supp_charsets[ftype].charset_code));
 		fl_set_object_lsize(amod_obj->AMOD_PGP_Input,
-							supp_charsets[ftype].font_size);
+			charset_size_from_code(supp_charsets[ftype].charset_code));
 	} else {
 		fl_set_object_lstyle(amod_obj->AMOD_Input,
-							 supp_charsets[def_charset].font_style);
+			charset_style_from_code(supp_charsets[ftype].charset_code));
 		fl_set_object_lsize(amod_obj->AMOD_Input,
-							supp_charsets[def_charset].font_size);
+			charset_size_from_code(supp_charsets[ftype].charset_code));
 		fl_set_object_lstyle(amod_obj->AMOD_PGP_Input,
-							 supp_charsets[def_charset].font_style);
+			charset_style_from_code(supp_charsets[ftype].charset_code));
 		fl_set_object_lsize(amod_obj->AMOD_PGP_Input,
-							supp_charsets[def_charset].font_size);
+			charset_size_from_code(supp_charsets[ftype].charset_code));
 	}
 
 
@@ -1134,7 +1134,7 @@ static void edit_entry(AddressBookEntry *entry) {
 	Config.setFlags("aliasgeom", CF_NOTCHANGED);
 	w = 410;
 	h = 240;
-	sscanf(Config.getCString("aliasgeom", ""), "%d %d", &w, &h);
+	sscanf(Config.get("aliasgeom", "").c_str(), "%d %d", &w, &h);
 	display_entry(entry);
 	fl_set_form_minsize(alias_obj->aliased, 410, 240);
 	fl_set_form_maxsize(alias_obj->aliased, 600, 400);
