@@ -1,10 +1,10 @@
-/* $Id: choose_folder.h,v 1.7 2002/07/27 20:07:24 cfreeze Exp $ */
+/* $Id: choose_folder.h,v 1.11 2004/01/02 04:05:36 fesnel Exp $ */
 /*******************************************************************************
  *   This program is part of the XFMail email client.                          *
  *                                                                             *
  *   Copyright : (C) 1995-1998 Gennady B. Sorokopud (gena@NetVision.net.il)    *
  *               (C) 1995 Ugen. J. S. Antsilevich (ugen@latte.worldbank.org)   *
- *               (C) 1998-2002 by the Archimedes Project                       *
+ *               (C) 1998-2004 by the Archimedes Project                       *
  *                   http://sourceforge.net/projects/archimedes                *
  *                                                                             *
  *             --------------------------------------------                    *
@@ -58,11 +58,10 @@ typedef void (*addr_dbl_cb)(struct _mail_addr *addr, int type, int data);
 extern struct _mail_addr *addr_book(int *addr_type, addr_dbl_cb callback, int data);
 extern struct _mail_addr *find_alias(char *name);
 
-#ifdef HAVE_LDAP
+#ifdef WITH_LDAP
 extern struct _mail_addr *find_ldap_expansion(char * name);
 #endif
 
-extern struct _mail_addr *expand_addr_list(struct _mail_msg *msg, struct _mail_addr *addr);
 extern void mailrc_import_aliases(char *fname);
 extern void pine_import_aliases(char *fname);
 extern void text_import_aliases(char *fname);
@@ -82,7 +81,6 @@ extern void log_win();
 extern void xfm_log_close_fd();
 extern void xfm_log_str(char * str);
 extern struct _mime_msg *compose_attachment(struct _mime_msg *omime);
-extern void PGP_Timer_Call(FL_OBJECT *obj, long param);
 extern void load_signatures();
 extern void free_signatures();
 extern void keymap_conf();
