@@ -1,10 +1,10 @@
-/* $Id: config.cpp,v 1.11 2002/12/05 20:34:47 fesnel Exp $ */
+/* $Id: config.cpp,v 1.14 2004/01/02 04:05:36 fesnel Exp $ */
 /*******************************************************************************
  *   This program is part of the XFMail email client.                          *
  *                                                                             *
  *   Copyright : (C) 1995-1998 Gennady B. Sorokopud (gena@NetVision.net.il)    *
  *               (C) 1995 Ugen. J. S. Antsilevich (ugen@latte.worldbank.org)   *
- *               (C) 1998-2002 by the Archimedes Project                       *
+ *               (C) 1998-2004 by the Archimedes Project                       *
  *                   http://sourceforge.net/projects/archimedes                *
  *                                                                             *
  *             --------------------------------------------                    *
@@ -57,7 +57,7 @@ static FD_config_viewedit *config_viewedit;
 static FD_config_send *config_send;
 static FD_config_receive *config_receive;
 static FD_config_news *config_news;
-#ifdef HAVE_LDAP
+#ifdef WITH_LDAP
 static FD_config_ldap *config_ldap;
 #endif
 
@@ -94,7 +94,7 @@ static void handle_config_misc_input() {
 	handle_smtp_input(config_send);
 	handle_inc_input(config_receive);
 	handle_news_input(config_news);
-#ifdef HAVE_LDAP
+#ifdef WITH_LDAP
 	handle_ldap_input(config_ldap);
 #endif
 }
@@ -119,7 +119,7 @@ static void init_config_misc() {
 	view_conf(0, config_viewedit);
 	edit_conf(0, config_viewedit);
 	news_conf(0, config_news);
-#ifdef HAVE_LDAP
+#ifdef WITH_LDAP
 	ldap_conf(0, config_ldap);
 #endif
 }
@@ -172,7 +172,7 @@ static void init_config_misc_default(int dnr) {
 		case 6:
 			news_conf(1, config_news);
 			break;
-#ifdef HAVE_LDAP
+#ifdef WITH_LDAP
 		case 7:
 			ldap_conf(1, config_ldap);
 			break;
@@ -274,7 +274,7 @@ void xfm_config_new(long dnr) {
 		config_send = create_form_config_send();
 		config_receive = create_form_config_receive();
 		config_news = create_form_config_news();
-#ifdef HAVE_LDAP
+#ifdef WITH_LDAP
 		config_ldap = create_form_config_ldap();
 #endif
 		fl_addto_tabfolder(config_misc_form->tab, "General",
@@ -289,7 +289,7 @@ void xfm_config_new(long dnr) {
 						   config_receive->config_receive);
 		fl_addto_tabfolder(config_misc_form->tab, "NEWS",
 						   config_news->config_news);
-#ifdef HAVE_LDAP
+#ifdef WITH_LDAP
 		fl_addto_tabfolder(config_misc_form->tab, "LDAP",
 						   config_ldap->config_ldap);
 #endif
