@@ -1,10 +1,10 @@
-/* $Id: configform.h,v 1.7 2002/12/05 20:34:47 fesnel Exp $ */
+/* $Id: configform.h,v 1.10 2004/01/02 04:05:36 fesnel Exp $ */
 /*******************************************************************************
  *   This program is part of the XFMail email client.                          *
  *                                                                             *
  *   Copyright : (C) 1995-1998 Gennady B. Sorokopud (gena@NetVision.net.il)    *
  *               (C) 1995 Ugen. J. S. Antsilevich (ugen@latte.worldbank.org)   *
- *               (C) 1998-2002 by the Archimedes Project                       *
+ *               (C) 1998-2004 by the Archimedes Project                       *
  *                   http://sourceforge.net/projects/archimedes                *
  *                                                                             *
  *             --------------------------------------------                    *
@@ -76,7 +76,7 @@ extern void header_conf(int,FD_config_header*);
 extern void handle_header_input(FD_config_header*);
 extern void news_conf(int,FD_config_news*);
 extern void handle_news_input(FD_config_news*);
-#ifdef HAVE_LDAP
+#ifdef WITH_LDAP
 extern void ldap_conf(int,FD_config_ldap *);
 extern void handle_ldap_input(FD_config_ldap*);
 #endif
