@@ -1,10 +1,10 @@
-/* $Id: faces.cpp,v 1.7 2002/01/26 03:14:54 fesnel Exp $ */
+/* $Id: faces.cpp,v 1.12 2004/01/02 04:05:36 fesnel Exp $ */
 /*******************************************************************************
  *   This program is part of the XFMail email client.                          *
  *                                                                             *
  *   Copyright : (C) 1995-1998 Gennady B. Sorokopud (gena@NetVision.net.il)    *
  *               (C) 1995 Ugen. J. S. Antsilevich (ugen@latte.worldbank.org)   *
- *               (C) 1998-2002 by the Archimedes Project                       *
+ *               (C) 1998-2004 by the Archimedes Project                       *
  *                   http://sourceforge.net/projects/archimedes                *
  *                                                                             *
  *             --------------------------------------------                    *
@@ -44,12 +44,11 @@
 #include <cfgfile.h>
 #include "configform.h"
 
-#ifdef FACES
-	#include <compface.h>
-#endif
-
+#ifdef WITH_FACES
+#include <compface.h>
 #define ATT_XPM
 #include <pixmaps.h>
+#endif
 
 #ifndef HAVE_XREADBITMAPFILEDATE
 extern int XReadBitmapFileData(const char *, unsigned int *,
@@ -59,13 +58,15 @@ extern int XReadBitmapFileData(const char *, unsigned int *,
 
 extern cfgfile Config;
 static FD_config_faces *face_obj;
+#ifdef WITH_FACES
 static int ready = 0;
 static char face[400] = { 0x00};
+#endif
 int xbmfirst;
 
 int addr_to_path(struct _mail_addr *ad, char *fpath, int n);
 
-#ifdef FACES
+#ifdef WITH_FACES
 unsigned char bitswaptbl[256] = {
 	0x00, 0x80, 0x40, 0xc0, 0x20, 0xa0, 0x60, 0xe0,
 	0x10, 0x90, 0x50, 0xd0, 0x30, 0xb0, 0x70, 0xf0,
@@ -113,7 +114,7 @@ char *xbm_to_face() {
 	if(face[0] != '\0')
 		return face;
 
-	strcpy(file, Config.getCString("myface", ""));
+	strcpy(file, Config.get("myface", "").c_str());
 	if(strlen(file) < 2)
 		return NULL;
 
@@ -246,7 +247,7 @@ void update_faces(struct _mail_msg *msg) {
 		return;
 
 	strcpy(bfpath,
-		   Config.getCString("facepath", "/usr/local/faces"));
+		   Config.get("facepath", "/usr/local/faces").c_str());
 	if(strchr(fpath, '/'))
 		snprintf(buf, sizeof(buf), "%s/%s/face.xbm", bfpath, fpath);
 	else
@@ -434,7 +435,7 @@ char *find_face(struct _mail_addr *addr, int *ftype) {
 	char bfpath[255];
 
 	strcpy(bfpath,
-		   Config.getCString("facepath", "/usr/local/faces"));
+		   Config.get("facepath", "/usr/local/faces").c_str());
 	if(!addr)
 		return NULL;
 
@@ -464,7 +465,7 @@ void Faces_Use_Call(FL_OBJECT * obj, long param) {
 }
 
 void Faces_Myface_Call(FL_OBJECT * obj, long param) {
-#ifdef  FACES
+#ifdef  WITH_FACES
 	char *ffile;
 
 	ffile = (char *) fl_get_input(obj);
@@ -487,7 +488,7 @@ void Faces_Myface_Call(FL_OBJECT * obj, long param) {
 }
 
 void Face_File_Choose_Call(FL_OBJECT * obj, long param) {
-#ifdef  FACES
+#ifdef  WITH_FACES
 	char *ffile;
 
 	fl_set_fselector_title("Choose your face file");
@@ -523,10 +524,9 @@ void Faces_Update_Call(FL_OBJECT * obj, long param) {
 void faces_conf(int set_default, FD_config_faces * form) {
 	face_obj = form;
 
-#ifdef  FACES
+#ifdef  WITH_FACES
 	fl_set_input(face_obj->Faces_Path,
-				 Config.getCStringDefault("facepath", "/usr/local/faces", 
-						 set_default));
+				 Config.get("facepath", "/usr/local/faces", set_default).c_str());
 	fl_set_button(face_obj->Faces_Use,
 				  Config.getIntDefault("usefaces", 0, set_default));
 	fl_set_button(face_obj->Faces_Bmp,
@@ -544,9 +544,9 @@ void faces_conf(int set_default, FD_config_faces * form) {
 		fl_hide_object(face_obj->Face_Bitmap);
 	} else {
 		fl_set_input(face_obj->Faces_Myface,
-					 Config.getCStringDefault("myface", "", set_default));
+					 Config.get("myface", "", set_default).c_str());
 		fl_set_bitmap_file(face_obj->Face_Bitmap,
-						   Config.getCStringDefault("myface", "", set_default));
+						   Config.get("myface", "", set_default).c_str());
 	}
 #else
 	fl_set_input(face_obj->Faces_Path,"UNAVAILABLE NOT COMPILED IN");
@@ -556,7 +556,7 @@ void faces_conf(int set_default, FD_config_faces * form) {
 void handle_faces_input(FD_config_faces * form) {
 	face_obj = form;
 
-#ifdef  FACES
+#ifdef  WITH_FACES
 	Config.set("facepath", (char *) fl_get_input(face_obj->Faces_Path));
 	Config.set("myface", (char *) fl_get_input(face_obj->Faces_Myface));
 	Config.set("usefaces", fl_get_button(face_obj->Faces_Use));
