@@ -1,10 +1,10 @@
-/* $Id: help.cpp,v 1.6 2002/01/26 03:14:54 fesnel Exp $ */
+/* $Id: help.cpp,v 1.9 2004/01/02 04:05:36 fesnel Exp $ */
 /*******************************************************************************
  *   This program is part of the XFMail email client.                          *
  *                                                                             *
  *   Copyright : (C) 1995-1998 Gennady B. Sorokopud (gena@NetVision.net.il)    *
  *               (C) 1995 Ugen. J. S. Antsilevich (ugen@latte.worldbank.org)   *
- *               (C) 1998-2002 by the Archimedes Project                       *
+ *               (C) 1998-2004 by the Archimedes Project                       *
  *                   http://sourceforge.net/projects/archimedes                *
  *                                                                             *
  *             --------------------------------------------                    *
@@ -105,7 +105,7 @@ void help(int chapter) {
 	Config.setFlags("helpgeom", CF_NOTCHANGED);
 	w = 500;
 	h = 300;
-	sscanf(Config.getCString("helpgeom", ""), "%d %d", &w, &h);
+	sscanf(Config.get("helpgeom", "").c_str(), "%d %d", &w, &h);
 	if(main_form)
 		fl_set_initial_placement(help_obj->Help_Form, main_form->x,
 								 main_form->y, w, h);
