@@ -1,10 +1,10 @@
-/* $Id: imap_conf.cpp,v 1.12 2002/07/11 02:28:19 cfreeze Exp $ */
+/* $Id: imap_conf.cpp,v 1.17 2004/01/02 04:05:36 fesnel Exp $ */
 /*******************************************************************************
  *   This program is part of the XFMail email client.                          *
  *                                                                             *
  *   Copyright : (C) 1995-1998 Gennady B. Sorokopud (gena@NetVision.net.il)    *
  *               (C) 1995 Ugen. J. S. Antsilevich (ugen@latte.worldbank.org)   *
- *               (C) 1998-2002 by the Archimedes Project                       *
+ *               (C) 1998-2004 by the Archimedes Project                       *
  *                   http://sourceforge.net/projects/archimedes                *
  *                                                                             *
  *             --------------------------------------------                    *
@@ -63,6 +63,12 @@ void IMAP_Pwd_Call(FL_OBJECT * obj, long param) {
 void IMAP_Use_Trash_Call(FL_OBJECT * obj, long param) {
 }
 
+void IMAP_Use_SSL_Call(FL_OBJECT * obj, long param) {
+}
+
+void IMAP_Use_Single_Quotes(FL_OBJECT * obj, long param) {
+}
+
 void IMAP_Store_Pwd_Call(FL_OBJECT * obj, long param) {
 	if(fl_get_button(imap_acc_obj->IMAP_Store_Pwd))
 		fl_show_alert("WARNING", "This is very unsecure option",
@@ -135,27 +141,22 @@ void imap_acc(struct _retrieve_src *source) {
 	fl_set_input(imap_acc_obj->IMAP_Pwd, imap->password);
 	fl_set_input(imap_acc_obj->IMAP_Extra, imap->list);
 
-	fl_set_button(imap_acc_obj->IMAP_Autocon,
-				  (imap->flags & ISRC_AUTOCON) ? 1 : 0);
-	fl_set_button(imap_acc_obj->IMAP_Store_Pwd,
-				  (imap->flags & ISRC_STOREPWD) ? 1 : 0);
-	fl_set_button(imap_acc_obj->IMAP_Log,
-				  (imap->flags & ISRC_LOGSESSION) ? 1 : 0);
-	fl_set_button(imap_acc_obj->IMAP_Use_Trash,
-				  (imap->flags & ISRC_TRASH) ? 1 : 0);
-	fl_set_button(imap_acc_obj->IMAP_Cache,
-				  (imap->flags & ISRC_CACHE) ? 1 : 0);
-	fl_set_button(imap_acc_obj->IMAP_NExpunge,
-				  (imap->flags & ISRC_NOEXPUNGE) ? 1 : 0);
-	fl_set_button(imap_acc_obj->IMAP_Retrieve,
-				  (imap->flags & ISRC_RETRIEVE) ? 1 : 0);
+	fl_set_button(imap_acc_obj->IMAP_Autocon, (imap->flags & ISRC_AUTOCON) ? 1 : 0);
+	fl_set_button(imap_acc_obj->IMAP_Store_Pwd, (imap->flags & ISRC_STOREPWD) ? 1 : 0);
+	fl_set_button(imap_acc_obj->IMAP_Log, (imap->flags & ISRC_LOGSESSION) ? 1 : 0);
+	fl_set_button(imap_acc_obj->IMAP_Use_Trash, (imap->flags & ISRC_TRASH) ? 1 : 0);
+	fl_set_button(imap_acc_obj->IMAP_Cache, (imap->flags & ISRC_CACHE) ? 1 : 0);
+	fl_set_button(imap_acc_obj->IMAP_NExpunge, (imap->flags & ISRC_NOEXPUNGE) ? 1 : 0);
+	fl_set_button(imap_acc_obj->IMAP_Retrieve, (imap->flags & ISRC_RETRIEVE) ? 1 : 0);
+#ifdef notyet
+	fl_set_button(imap_acc_obj->IMAP_Use_SSL, (imap->flags & ISRC_SSL) ? 1 : 0);
+#endif
+	fl_set_button(imap_acc_obj->IMAP_SingleQuotes, (imap->flags & ISRC_SQUOTES) ? 1 : 0);	
 
-	fl_show_form(imap_acc_obj->acc_imap, FL_PLACE_CENTER, FL_TRANSIENT,
-				 "IMAP server");
+	fl_show_form(imap_acc_obj->acc_imap, FL_PLACE_CENTER, FL_TRANSIENT, "IMAP server");
 	fl_do_only_forms();
 
-	strncpy(imap->hostname, fl_get_input(imap_acc_obj->IMAP_Host),
-			MAX_HOST - 1);
+	strncpy(imap->hostname, fl_get_input(imap_acc_obj->IMAP_Host), MAX_HOST - 1);
 	imap->hostname[MAX_HOST - 1] = '\0';
 	strncpy(imap->service, fl_get_input(imap_acc_obj->IMAP_Port), 15);
 	imap->service[15] = '\0';
@@ -183,6 +184,12 @@ void imap_acc(struct _retrieve_src *source) {
 		imap->flags |= ISRC_NOEXPUNGE;
 	if(fl_get_button(imap_acc_obj->IMAP_Retrieve))
 		imap->flags |= ISRC_RETRIEVE;
+#ifdef notyet
+	if(fl_get_button(imap_acc_obj->IMAP_Use_SSL))
+		imap->flags |= ISRC_SSL;
+#endif
+	if(fl_get_button(imap_acc_obj->IMAP_SingleQuotes))
+		imap->flags |= ISRC_SQUOTES;
 
 	fl_hide_form(imap_acc_obj->acc_imap);
 	fl_free_form(imap_acc_obj->acc_imap);
