@@ -1,10 +1,10 @@
-/* $Id: inc.cpp,v 1.23 2002/11/24 03:36:57 fesnel Exp $ */
+/* $Id: inc.cpp,v 1.28 2004/01/02 04:05:36 fesnel Exp $ */
 /*******************************************************************************
  *   This program is part of the XFMail email client.                          *
  *                                                                             *
  *   Copyright : (C) 1995-1998 Gennady B. Sorokopud (gena@NetVision.net.il)    *
  *               (C) 1995 Ugen. J. S. Antsilevich (ugen@latte.worldbank.org)   *
- *               (C) 1998-2002 by the Archimedes Project                       *
+ *               (C) 1998-2004 by the Archimedes Project                       *
  *                   http://sourceforge.net/projects/archimedes                *
  *                                                                             *
  *             --------------------------------------------                    *
@@ -244,11 +244,14 @@ void Inc_Add_Call(FL_OBJECT * obj, long param) {
 
 		case RSRC_IMAP:
 			imap_source(&src);
-			set_menu_imap();
 			break;
 	}
 
 	retrieve_srcs.push_back(src);
+	/* Add IMAP source to IMAP menu */
+	if (src.type == RSRC_IMAP)
+		set_menu_imap();
+
 	fl_addto_browser(inc_obj->Inc_Sources, get_src_line(src.name));
 	fl_select_browser_line(inc_obj->Inc_Sources,
 	    fl_get_browser_maxline(inc_obj->Inc_Sources));
@@ -567,7 +570,7 @@ void inc_conf(int set_default, FD_config_receive * form) {
 			fl_deactivate_object(inc_obj->Inc_Command);
 			fl_deactivate_object(inc_obj->Inc_EsdHost);
 			fl_set_input(inc_obj->Inc_Play,
-						 Config.getCStringDefault("play", "", set_default));
+						 Config.get("play", "", set_default).c_str());
 		   	break;
 
 		case 3:
@@ -580,7 +583,7 @@ void inc_conf(int set_default, FD_config_receive * form) {
 			fl_activate_object(inc_obj->Inc_Command);
 			fl_deactivate_object(inc_obj->Inc_EsdHost);
 			fl_set_input(inc_obj->Inc_Command,
-						 Config.getCStringDefault("play", "", set_default)); 
+						 Config.get("play", "", set_default).c_str()); 
 			break;
 
 		case 4:
@@ -593,7 +596,7 @@ void inc_conf(int set_default, FD_config_receive * form) {
 			fl_deactivate_object(inc_obj->Inc_Command);
 			fl_activate_object(inc_obj->Inc_EsdHost);
 			fl_set_input(inc_obj->Inc_EsdHost,
-						 Config.getCStringDefault("esd_host", "localhost", set_default)); 
+						 Config.get("esd_host", "localhost", set_default).c_str()); 
 			break;
 		default:
 			fl_set_button(inc_obj->Inc_NSound, 1);
@@ -779,7 +782,8 @@ int load_sources() {
 		"WARNING: no retrieve sources/accounts defined");
 	return 0;
   }
-  
+
+  retrieve_srcs.clear();
   while(fgets(buf, sizeof(buf), sfd)) {
 	if(*buf != '@')
 	  continue;
