@@ -1,10 +1,10 @@
-/* $Id: keymap.cpp,v 1.6 2002/01/26 03:14:54 fesnel Exp $ */
+/* $Id: keymap.cpp,v 1.9 2004/01/02 04:05:36 fesnel Exp $ */
 /*******************************************************************************
  *   This program is part of the XFMail email client.                          *
  *                                                                             *
  *   Copyright : (C) 1995-1998 Gennady B. Sorokopud (gena@NetVision.net.il)    *
  *               (C) 1995 Ugen. J. S. Antsilevich (ugen@latte.worldbank.org)   *
- *               (C) 1998-2002 by the Archimedes Project                       *
+ *               (C) 1998-2004 by the Archimedes Project                       *
  *                   http://sourceforge.net/projects/archimedes                *
  *                                                                             *
  *             --------------------------------------------                    *
@@ -673,7 +673,7 @@ void Keymap_Digraphs_Call(FL_OBJECT * obj, long param) {
 	Config.setFlags("digrgeom", CF_NOTCHANGED);
 	w = 500;
 	h = 300;
-	sscanf(Config.getCString("digrgeom", ""), "%d %d", &w, &h);
+	sscanf(Config.get("digrgeom", "").c_str(), "%d %d", &w, &h);
 	fl_deactivate_object(help_obj->HelpTop);
 	fl_deactivate_object(help_obj->HelpBack);
 	fl_set_object_callback(help_obj->Done_Help, NULL, 0);
