@@ -1,10 +1,10 @@
-/* $Id: misc.cpp,v 1.9 2002/01/26 03:14:54 fesnel Exp $ */
+/* $Id: misc.cpp,v 1.13 2004/01/02 04:05:36 fesnel Exp $ */
 /*******************************************************************************
  *   This program is part of the XFMail email client.                          *
  *                                                                             *
  *   Copyright : (C) 1995-1998 Gennady B. Sorokopud (gena@NetVision.net.il)    *
  *               (C) 1995 Ugen. J. S. Antsilevich (ugen@latte.worldbank.org)   *
- *               (C) 1998-2002 by the Archimedes Project                       *
+ *               (C) 1998-2004 by the Archimedes Project                       *
  *                   http://sourceforge.net/projects/archimedes                *
  *                                                                             *
  *             --------------------------------------------                    *
@@ -76,40 +76,38 @@ void misc_conf(int set_default, FD_config_misc * form) {
 
 	snprintf(buf, sizeof(buf), "%s/Mail", homedir);
 	fl_set_input(misc_obj->Misc_Mail_Dir,
-				 Config.getCStringDefault("maildir", buf,
-										 set_default));
+				 Config.get("maildir", buf, set_default).c_str());
 	fl_set_input(misc_obj->Misc_From,
-				 Config.getCStringDefault("from", "",
-										 set_default));
+				 Config.get("from", "", set_default).c_str());
 	fl_set_input(misc_obj->Misc_LPR,
-				 Config.getCStringDefault("print",
+				 Config.get("print",
 										 get_print_command(NULL),
-										 set_default));
+										 set_default).c_str());
 	fl_set_input(misc_obj->Misc_Printer,
-				 Config.getCStringDefault("printer", "lp",
-										 set_default));
+				 Config.get("printer", "lp",
+										 set_default).c_str());
 	fl_set_input(misc_obj->Misc_Cache_Dir,
-					 Config.getCStringDefault("cachedir",
-											 configdir, set_default));
+					 Config.get("cachedir",
+											 configdir, set_default).c_str());
 
 	if(Config.exist("organization"))
 		fl_set_input(misc_obj->Misc_Org,
-					 Config.getCStringDefault("organization", "", set_default));
+					 Config.get("organization", "", set_default).c_str());
 	else
 		fl_set_input(misc_obj->Misc_Org, "");
 
 	if(Config.exist("replyto"))
 		fl_set_input(misc_obj->Misc_RTO,
-					 Config.getCStringDefault("replyto", "", set_default));
+					 Config.get("replyto", "", set_default).c_str());
 	else
 		fl_set_input(misc_obj->Misc_RTO, "");
 
 	fl_set_input(misc_obj->Misc_Cache,
-				 Config.getCStringDefault("mincache", "512", set_default));
+				 Config.get("mincache", "512", set_default).c_str());
 	fl_set_button(misc_obj->Misc_SIconized,
 				  Config.getIntDefault("starticon", 0, set_default));
 	fl_set_button(misc_obj->Misc_Empty,
-				  Config.getIntDefault("emptytrash", 1, set_default));
+				  Config.getIntDefault("emptytrash", 0, set_default));
 	fl_set_button(misc_obj->Misc_SLog,
 				  Config.getIntDefault("startlog", 0, set_default));
 	fl_set_button(misc_obj->Misc_TTips,
@@ -133,10 +131,7 @@ void handle_misc_input(FD_config_misc * form) {
 	misc_obj = form;
 
 	Config.set("from", (char *) fl_get_input(misc_obj->Misc_From));
-	if(
-	  ((ma
-		=
-		get_address(Config.getCString("from", ""), ADDR_GET_FIRST)) == NULL)
+	if( ((ma = get_address(Config.get("from", "").c_str(), ADDR_GET_FIRST)) == NULL)
 	  || ((p = strchr(ma->addr, '@')) == NULL)
 	  || (strchr(p, '.') == NULL)) display_msg(MSG_WARN,
 											   "Your E-Mail address (From field)",
@@ -226,7 +221,7 @@ void display_headers() {
 	for(i = 1; i <= MAX_EXTRA_HEADERS; i++) {
 		sprintf(hline, "ExtraHeader%d", i);
 		if(Config.exist(hline)) {
-			strcpy(hline, Config.getCString(hline, ""));
+			strcpy(hline, Config.get(hline, "").c_str());
 			if((hf = get_field(hline)) == NULL) {
 				Config.remove(hline);
 				continue;
