@@ -1,10 +1,10 @@
-/* $Id: pgp.cpp,v 1.17 2002/07/11 01:28:19 cfreeze Exp $ */
+/* $Id: pgp.cpp,v 1.22 2004/01/02 04:05:36 fesnel Exp $ */
 /*******************************************************************************
  *   This program is part of the XFMail email client.                          *
  *                                                                             *
  *   Copyright : (C) 1995-1998 Gennady B. Sorokopud (gena@NetVision.net.il)    *
  *               (C) 1995 Ugen. J. S. Antsilevich (ugen@latte.worldbank.org)   *
- *               (C) 1998-2002 by the Archimedes Project                       *
+ *               (C) 1998-2004 by the Archimedes Project                       *
  *                   http://sourceforge.net/projects/archimedes                *
  *                                                                             *
  *             --------------------------------------------                    *
@@ -72,13 +72,11 @@ char *input_passphrase() {
 	FD_Passphrase *pass;
 	int ptimer = Config.getInt("pgptimer", 120);
 	if(!phrase) { /* no passphrase, go and get it */
-		/* goto retp; */
-
   	  pass = create_form_Passphrase();
 
   	  fl_show_form(pass->Passphrase, FL_PLACE_MOUSE, FL_TRANSIENT,
 				  "Input Passphrase");
-          fl_set_input_maxchars(pass->Input_Passphrase,0);
+      fl_set_input_maxchars(pass->Input_Passphrase,0);
   	  fl_do_only_forms();
   	  phrase = strdup((char *) fl_get_input(pass->Input_Passphrase));
   	  scramble(phrase);
@@ -110,17 +108,13 @@ char *input_passphrase() {
  * passphrase: if mode==DECODE, or mode==SIGN, the pass phrase
  * see also "pgp/doc/appnote.doc"
  */
-
 void PGP_Conf_Lookup_CB(FL_OBJECT * obj, long data) {
 	int keyid, ftype;
 	char buf[12];
 	struct _mail_addr *addr;
 
-	addr =
-	get_address(Config.getCString("from", ""),
-				ADDR_GET_FIRST);
-	keyid =
-	PGP_Lookup_PGPId(addr ? get_charset_addr_line(NULL, addr, &ftype) :
+	addr = get_address(Config.getString("from", "").c_str(),ADDR_GET_FIRST);
+	keyid = PGP_Lookup_PGPId(addr ? get_charset_addr_line(NULL, addr, &ftype) :
 					 user_n, pgp_obj->config_pgp);
 	if(addr)
 		discard_address(addr);
@@ -136,34 +130,38 @@ void PGP_Conf_Lookup_CB(FL_OBJECT * obj, long data) {
 void pgp_conf(int set_default, FD_config_pgp * form) {
 	pgp_obj = form;
 
+    string sPgpProg = Config.get("pgp", _PATH_PGP, set_default);
+	string sPgpKeyRing = Config.get("pgpkeyring", "", set_default);
+    string sPgpKeyServer = Config.get("pgpkeyserver", "", set_default);
+    string sPgpUser = Config.get("pgpuser", user_n, set_default);
+
+    int iPgpSign = Config.getIntDefault("pgpsign", 0, set_default);
+    int iPgpMime = Config.getIntDefault("pgpmime", 0, set_default) + 1;
+    int iPgpUseKeyRing = Config.getIntDefault("pgpusekeyring", 0, set_default);
+    int iPgpUseHttp = Config.getIntDefault("pgpusehttp", 0, set_default);
+    int iPgpEncryptBcc = Config.getIntDefault("pgp_encrypt_bcc", 0, set_default);
+
 	fl_clear_choice(pgp_obj->PGP_Mime);
 	fl_addto_choice(pgp_obj->PGP_Mime, "Text");
 	fl_addto_choice(pgp_obj->PGP_Mime, "application/pgp");
 	fl_addto_choice(pgp_obj->PGP_Mime, "Multipart");
-	fl_set_choice(pgp_obj->PGP_Mime,
-				  Config.getIntDefault("pgpmime", 0, set_default) + 1);
-	fl_set_input(pgp_obj->PGP_Prog,
-				 Config.getCStringDefault("pgp", _PATH_PGP, set_default));
-	fl_set_input(pgp_obj->PGP_Keyring,
-				 Config.getCStringDefault("pgpkeyring", "", set_default));
-	fl_set_input(pgp_obj->PGP_KeyServer,
-				 Config.getCStringDefault("pgpkeyserver", "", set_default));
-	fl_set_input(pgp_obj->PGP_User,
-				 Config.getCStringDefault("pgpuser", user_n, set_default));
-	fl_set_button(pgp_obj->PGP_Sign,
-				  Config.getIntDefault("pgpsign", 0, set_default));
-	fl_set_button(pgp_obj->PGP_Use_Keyring,
-				  Config.getIntDefault("pgpusekeyring", 0, set_default));
-	fl_set_button(pgp_obj->PGP_Use_HTTP,
-				  Config.getIntDefault("pgpusehttp", 0, set_default));
-	fl_set_button(pgp_obj->PGP_Encrypt_Bcc,
-				  Config.getIntDefault("pgp_encrypt_bcc", 0, set_default));
+	fl_set_choice(pgp_obj->PGP_Mime, iPgpMime);
+	fl_set_input(pgp_obj->PGP_Prog, sPgpProg.c_str());
+	fl_set_input(pgp_obj->PGP_Keyring,sPgpKeyRing.c_str());
+	fl_set_input(pgp_obj->PGP_KeyServer, sPgpKeyServer.c_str());
+	fl_set_input(pgp_obj->PGP_User, sPgpUser.c_str());
+	fl_set_button(pgp_obj->PGP_Sign, iPgpSign);
+	fl_set_button(pgp_obj->PGP_Use_Keyring, iPgpUseKeyRing);
+	fl_set_button(pgp_obj->PGP_Use_HTTP, iPgpUseHttp);
+	fl_set_button(pgp_obj->PGP_Encrypt_Bcc, iPgpEncryptBcc);
 	fl_clear_choice(pgp_obj->PGP_500);
 	fl_addto_choice(pgp_obj->PGP_500, "PGP 2.6");
 	fl_addto_choice(pgp_obj->PGP_500, "PGP 5.0");
 	fl_addto_choice(pgp_obj->PGP_500, "PGP 6.5");
 	fl_addto_choice(pgp_obj->PGP_500, "GnuPG");
 	fl_set_choice(pgp_obj->PGP_500, get_pgpchoice(pgp_obj, set_default));
+
+    return;
 }
 
 int get_pgpchoice(FD_config_pgp * obj, int set_default) {
@@ -181,16 +179,31 @@ int get_pgpchoice(FD_config_pgp * obj, int set_default) {
 
 void handle_pgp_input(FD_config_pgp * form) {
 	pgp_obj = form;
-	Config.set("pgp", (char *) fl_get_input(pgp_obj->PGP_Prog));
-	Config.set("pgpkeyring", (char *) fl_get_input(pgp_obj->PGP_Keyring));
-	Config.set("pgpkeyserver", (char *) fl_get_input(pgp_obj->PGP_KeyServer));
-	Config.set("pgpuser", (char *) fl_get_input(pgp_obj->PGP_User));
-	Config.set("pgpmime", fl_get_choice(pgp_obj->PGP_Mime) - 1);
-	Config.set("pgpsign", fl_get_button(pgp_obj->PGP_Sign));
-	Config.set("pgpusekeyring", fl_get_button(pgp_obj->PGP_Use_Keyring));
-	Config.set("pgpusehttp", fl_get_button(pgp_obj->PGP_Use_HTTP));
-	Config.set("pgp_encrypt_bcc", fl_get_button(pgp_obj->PGP_Encrypt_Bcc));
-	Config.set("pgpversion", get_pgpversion(pgp_obj));
+
+    string sPgpProg = ((char *) fl_get_input(pgp_obj->PGP_Prog));
+    string sPgpKeyRing = ((char *) fl_get_input(pgp_obj->PGP_Keyring));
+    string sPgpKeyServer = ((char *) fl_get_input(pgp_obj->PGP_KeyServer));
+    string sPgpUser = ((char *) fl_get_input(pgp_obj->PGP_User));
+
+    int iPgpMime = fl_get_choice(pgp_obj->PGP_Mime) - 1;
+    int iPgpSign = fl_get_button(pgp_obj->PGP_Sign);
+    int iPgpUseKeyRing = fl_get_button(pgp_obj->PGP_Use_Keyring);
+    int iPgpUseHttp = fl_get_button(pgp_obj->PGP_Use_HTTP);
+    int iPgpEncryptBcc = fl_get_button(pgp_obj->PGP_Encrypt_Bcc);
+    int iPgpVersion = get_pgpversion(pgp_obj);
+
+	Config.set("pgp", sPgpProg);
+	Config.set("pgpkeyring", sPgpKeyRing);
+	Config.set("pgpkeyserver", sPgpKeyServer);
+	Config.set("pgpuser", sPgpUser);
+	Config.set("pgpmime", iPgpMime);
+	Config.set("pgpsign", iPgpSign);
+	Config.set("pgpusekeyring", iPgpUseKeyRing);
+	Config.set("pgpusehttp", iPgpUseHttp);
+	Config.set("pgp_encrypt_bcc", iPgpEncryptBcc);
+	Config.set("pgpversion", iPgpVersion);
+
+    return;
 }
 
 int get_pgpversion(FD_config_pgp * obj) {
@@ -219,24 +232,26 @@ unsigned long PGP_Lookup_PGPId(const char *name, FL_FORM * form) {
 	struct _pgp_keylist *keylist;
 	FL_OBJECT *obj;
 	int pgpvers = Config.getInt("pgpversion", PGP_DEFAULT_VERS);
+    string sPgpProg = Config.get("pgp", _PATH_PGP);
+
 	if(form_lookup_pgpid)
 		return 0;
 
 	strcpy(keyfile, get_temp_file("pgpkeys"));
 	if(pgpvers == 500)
-		snprintf(buf, sizeof(buf), "%sk +batchmode +language=en -l",
-				 Config.getCString("pgp", _PATH_PGP));
+		snprintf(buf, sizeof(buf), "%sk +batchmode +language=en -l", 
+                            sPgpProg.c_str());
 	if(pgpvers == 651)
 		 /* +compatible=on is dirty hack to avoid total rewriting of the
 	 "interpreter" down there. I'll do that later anyways */ 
 		snprintf(buf, sizeof(buf), "%s +batchmode +compatible=on +language=en -kv",
-				 Config.getCString("pgp", _PATH_PGP));		 
+                            sPgpProg.c_str());
 	if(pgpvers == 95)
 		snprintf(buf, sizeof(buf), "%s --batch --list-keys",
-				 Config.getCString("pgp", _PATH_PGP));
+                            sPgpProg.c_str());
 	if(pgpvers == 263)
 		snprintf(buf, sizeof(buf), "%s +batchmode +language=en -kv",
-				 Config.getCString("pgp", _PATH_PGP));
+                            sPgpProg.c_str());
 	init_pinfo(&pinfo);
 	pinfo.ofd = open(keyfile, O_WRONLY | O_CREAT, 00600);
 	pinfo.wait = WAIT_BG;
@@ -283,20 +298,20 @@ unsigned long PGP_Lookup_PGPId(const char *name, FL_FORM * form) {
 
 	fl_set_object_label(form_lookup_pgpid->PGP_Lookup, name);
 	fl_set_object_lstyle(form_lookup_pgpid->PGP_Lookup,
-						 supp_charsets[def_charset].font_style);
+		charset_style_from_code(supp_charsets[def_charset].charset_code));
 	fl_set_object_lsize(form_lookup_pgpid->PGP_Lookup,
-						supp_charsets[def_charset].font_size);
+						charset_size_from_code(supp_charsets[def_charset].charset_code));
 
 	fl_set_object_label(form_lookup_pgpid->PGP_selected_id, "");
 	fl_set_object_lstyle(form_lookup_pgpid->PGP_selected_id,
-						 supp_charsets[def_charset].font_style);
+						 charset_style_from_code(supp_charsets[def_charset].charset_code));
 	fl_set_object_lsize(form_lookup_pgpid->PGP_selected_id,
-						supp_charsets[def_charset].font_size);
+						charset_size_from_code(supp_charsets[def_charset].charset_code));
 
 	fl_set_browser_fontstyle(form_lookup_pgpid->PGP_Lookup_Browser,
-							 supp_charsets[def_charset].font_style);
+							 charset_style_from_code(supp_charsets[def_charset].charset_code));
 	fl_set_browser_fontsize(form_lookup_pgpid->PGP_Lookup_Browser,
-							supp_charsets[def_charset].font_size);
+							charset_size_from_code(supp_charsets[def_charset].charset_code));
 	fl_clear_browser(form_lookup_pgpid->PGP_Lookup_Browser);
 
 	/*
@@ -354,7 +369,6 @@ unsigned long PGP_Lookup_PGPId(const char *name, FL_FORM * form) {
 															 _pgp_keylist));
 		}
 
-
 		if(keylist == NULL)
 			break;
 
@@ -381,7 +395,7 @@ unsigned long PGP_Lookup_PGPId(const char *name, FL_FORM * form) {
 	Config.setFlags("pgpgeom", CF_NOTCHANGED);
 	w = 350;
 	h = 400;
-	sscanf(Config.getCString("pgpgeom", ""), "%d %d", &w, &h);
+	sscanf(Config.getString("pgpgeom", "").c_str(), "%d %d", &w, &h);
 	fl_set_form_minsize(form_lookup_pgpid->Lookup_PGPId, 350, 400);
 	fl_set_form_size(form_lookup_pgpid->Lookup_PGPId, w, h);
 	fl_show_form(form_lookup_pgpid->Lookup_PGPId,
