@@ -1,10 +1,10 @@
-/* $Id: pop_smtp.cpp,v 1.22 2002/12/05 20:34:47 fesnel Exp $ */
+/* $Id: pop_smtp.cpp,v 1.28 2004/01/02 04:05:36 fesnel Exp $ */
 /*******************************************************************************
  *   This program is part of the XFMail email client.                          *
  *                                                                             *
  *   Copyright : (C) 1995-1998 Gennady B. Sorokopud (gena@NetVision.net.il)    *
  *               (C) 1995 Ugen. J. S. Antsilevich (ugen@latte.worldbank.org)   *
- *               (C) 1998-2002 by the Archimedes Project                       *
+ *               (C) 1998-2004 by the Archimedes Project                       *
  *                   http://sourceforge.net/projects/archimedes                *
  *                                                                             *
  *             --------------------------------------------                    *
@@ -54,15 +54,13 @@ extern gPasswd Passwd;
 FD_POPacc *pacc_obj;
 static FD_config_send *smtp_obj;
 static FD_config_news *nntp_obj;
-#ifdef HAVE_LDAP
+#ifdef WITH_LDAP
 static FD_config_ldap *ldap_obj;
 #endif
 static FD_acc_pop *pop_acc_obj;
 static FD_acc_smtp *smtp_acc_obj;
 static int ready = 0;
 
-void pop_account_free();
-
 void SMTP_Host_Call(FL_OBJECT * obj, long param) {
 }
 
@@ -330,12 +328,9 @@ void nntp_account() {
 	fl_set_input_maxchars(pacc_obj->P_Username,POP_MAX_USERNAME_LEN);
 	fl_set_input_maxchars(pacc_obj->P_Password,POP_MAX_USERNAME_LEN);
 
-	fl_set_input(pacc_obj->P_Username,
-				 Config.getCString("nntpuser", user_n));
-	fl_set_input(pacc_obj->P_Password,
-				 Config.getCString("nntpasswd", ""));
-	fl_set_object_label(pacc_obj->P_Server,
-						Config.getCString("nntphost", "news"));
+	fl_set_input(pacc_obj->P_Username, Config.get("nntpuser", user_n).c_str());
+	fl_set_input(pacc_obj->P_Password, Config.get("nntpasswd", "").c_str());
+	fl_set_object_label(pacc_obj->P_Server, Config.get("nntphost", "news").c_str());
 	fl_set_object_label(pacc_obj->P_Title, "NNTP authorization on");
 	fl_set_object_focus(pacc_obj->POPacc, pacc_obj->P_Password);
 	fl_show_form(pacc_obj->POPacc, FL_PLACE_CENTER, FL_TRANSIENT,
@@ -399,18 +394,12 @@ void news_conf(int set_default, FD_config_news * form) {
 	fl_set_input_maxchars(nntp_obj->NNTP_Username,POP_MAX_USERNAME_LEN);
 	fl_set_input_maxchars(nntp_obj->NNTP_Password,POP_MAX_PASSWD_LEN);
 
-	fl_set_input(nntp_obj->NNTP_Host,
-				 Config.getCStringDefault("nntphost", "news", set_default));
-	fl_set_input(nntp_obj->NNTP_Port,
-				 Config.getCStringDefault("nntport", "119", set_default));
-	fl_set_input(nntp_obj->NNTP_Username,
-				 Config.getCStringDefault("nntpuser", user_n, set_default));
-	fl_set_input(nntp_obj->NNTP_Password,
-				 Config.getCStringDefault("nntpasswd", "", set_default));
-	fl_set_button(nntp_obj->NNTP_Store_Pwd,
-				  Config.getIntDefault("nntpstorpwd", 0, set_default));
-	fl_set_button(nntp_obj->NNTP_Authorize,
-				  Config.getIntDefault("nntpauth", 0, set_default));
+	fl_set_input(nntp_obj->NNTP_Host, Config.get("nntphost", "news", set_default).c_str());
+	fl_set_input(nntp_obj->NNTP_Port, Config.get("nntport", "119", set_default).c_str());
+	fl_set_input(nntp_obj->NNTP_Username, Config.get("nntpuser", user_n, set_default).c_str());
+	fl_set_input(nntp_obj->NNTP_Password, Config.get("nntpasswd", "", set_default).c_str());
+	fl_set_button(nntp_obj->NNTP_Store_Pwd, Config.getIntDefault("nntpstorpwd", 0, set_default));
+	fl_set_button(nntp_obj->NNTP_Authorize, Config.getIntDefault("nntpauth", 0, set_default));
 	fl_set_button(nntp_obj->NNTP_Log, (logging & LOG_NNTP) ? 1 : 0);
 	if(fl_get_button(nntp_obj->NNTP_Store_Pwd))
 		Config.setFlags("nntpasswd", CF_UNSECURE);
@@ -440,10 +429,8 @@ void handle_news_input(FD_config_news * form) {
 void smtp_conf(int set_default, FD_config_send * form) {
 
 	smtp_obj = form;
-	fl_set_input(smtp_obj->SMTP_Host,
-				 Config.getCStringDefault("smtphost", "127.0.0.1", set_default));
-	fl_set_input(smtp_obj->SMTP_Port,
-				 Config.getCStringDefault("smtport", "25", set_default));
+	fl_set_input(smtp_obj->SMTP_Host, Config.get("smtphost", "127.0.0.1", set_default).c_str());
+	fl_set_input(smtp_obj->SMTP_Port, Config.get("smtport", "25", set_default).c_str());
 	switch(Config.getIntDefault("smtpsend", 0, set_default)) {
 		case 0:
 			fl_set_button(smtp_obj->SMTP_Sendmail, 1);
@@ -462,27 +449,18 @@ void smtp_conf(int set_default, FD_config_send * form) {
 			break;
 	}
 
-	fl_set_input(smtp_obj->SMTP_POPSRC,
-				 Config.getCStringDefault("smtppopsrc", "", set_default));
-	fl_set_button(smtp_obj->SMTP_Bg,
-				  Config.getIntDefault("smtpbg", 0, set_default));
-	fl_set_button(smtp_obj->SMTP_Save,
-				  Config.getIntDefault("smtpsave", 0, set_default));
-	fl_set_button(smtp_obj->SMTP_Bcc,
-				  Config.getIntDefault("smtpbcc", 0, set_default));
-	fl_set_button(smtp_obj->SMTP_Off,
-				  Config.getIntDefault("smtpoffl", 0, set_default));
-	fl_set_button(smtp_obj->SMTP_DSN,
-				  Config.getIntDefault("smtpdsn", 0, set_default));
-	fl_set_input(smtp_obj->Misc_SMail,
-				 Config.getCStringDefault("sendmail", _PATH_SENDMAIL, set_default));
-	fl_set_input(smtp_obj->Sendmail_Opt,
-				 Config.getCStringDefault("sendmailopt", "-i",
-										 set_default));
-	fl_set_input(smtp_obj->Sendmail_DSN,
-				 Config.getCStringDefault("sendmaildsn",
+	fl_set_input(smtp_obj->SMTP_POPSRC, Config.get("smtppopsrc", "", set_default).c_str());
+	fl_set_button(smtp_obj->SMTP_Bg, Config.getIntDefault("smtpbg", 0, set_default));
+	fl_set_button(smtp_obj->SMTP_Save, Config.getIntDefault("smtpsave", 1, set_default));
+	fl_set_button(smtp_obj->SMTP_Bcc, Config.getIntDefault("smtpbcc", 0, set_default));
+	fl_set_button(smtp_obj->SMTP_Off, Config.getIntDefault("smtpoffl", 0, set_default));
+	fl_set_button(smtp_obj->SMTP_DSN, Config.getIntDefault("smtpdsn", 0, set_default));
+	fl_set_input(smtp_obj->Misc_SMail, Config.get("sendmail", _PATH_SENDMAIL, set_default).c_str());
+	fl_set_input(smtp_obj->Sendmail_Opt, Config.get("sendmailopt", "-i",
+										 set_default).c_str());
+	fl_set_input(smtp_obj->Sendmail_DSN, Config.get("sendmaildsn",
 										 "-R hdrs -N failure,delay,success",
-										 set_default));
+										 set_default).c_str());
 	fl_set_button(smtp_obj->SMTP_Log, (logging & LOG_SMTP) ? 1 : 0);
 }
 
@@ -516,14 +494,14 @@ void handle_smtp_input(FD_config_send * form) {
 	return;
 }
 
-#ifdef HAVE_LDAP
+#ifdef WITH_LDAP
 void ldap_conf(int set_default, FD_config_ldap * form) {
 
 	ldap_obj = form;
 
-	fl_set_input(ldap_obj->LDAPserver, Config.getCStringDefault("LDAPserver", "ldap.bigfoot.com", set_default));
-	fl_set_input(ldap_obj->LDAPport, Config.getCStringDefault("LDAPport", "389", set_default));
-	fl_set_input(ldap_obj->LDAPbase, Config.getCStringDefault("LDAPbase", "", set_default));
+	fl_set_input(ldap_obj->LDAPserver, Config.get("LDAPserver", "ldap.bigfoot.com", set_default).c_str());
+	fl_set_input(ldap_obj->LDAPport, Config.get("LDAPport", "389", set_default).c_str());
+	fl_set_input(ldap_obj->LDAPbase, Config.get("LDAPbase", "", set_default).c_str());
 	fl_set_counter_value(ldap_obj->LDAPmaxResults, (double) Config.getIntDefault("LDAPmaxResults", 20, set_default));
 
 	return;
