@@ -1,10 +1,10 @@
-/* $Id: rep_fwd.cpp,v 1.9 2002/01/26 03:14:55 fesnel Exp $ */
+/* $Id: rep_fwd.cpp,v 1.12 2004/01/02 04:05:36 fesnel Exp $ */
 /*******************************************************************************
  *   This program is part of the XFMail email client.                          *
  *                                                                             *
  *   Copyright : (C) 1995-1998 Gennady B. Sorokopud (gena@NetVision.net.il)    *
  *               (C) 1995 Ugen. J. S. Antsilevich (ugen@latte.worldbank.org)   *
- *               (C) 1998-2002 by the Archimedes Project                       *
+ *               (C) 1998-2004 by the Archimedes Project                       *
  *                   http://sourceforge.net/projects/archimedes                *
  *                                                                             *
  *             --------------------------------------------                    *
@@ -72,22 +72,14 @@ void reply_conf(int set_default, FD_config_reply * form) {
 	fl_addto_choice(reply_obj->Reply_All, "ask");
 	fl_set_choice(reply_obj->Reply_All,
 				  Config.getIntDefault("inclrecp", 3, set_default));
-	fl_set_input(reply_obj->Reply_Prefix,
-				 Config.getCStringDefault("prefix", ">", set_default));
-	fl_set_input(reply_obj->Reply_RePrefix,
-				 Config.getCStringDefault("reprefix", "RE:", set_default));
-	fl_set_input(reply_obj->Reply_FwdPrefix,
-				 Config.getCStringDefault("fwdprefix", "FWD:", set_default));
-	fl_set_input(reply_obj->Reply_Str,
-				 Config.getCStringDefault("replystr", "On %d %f wrote:%n",
-										 set_default));
-	fl_set_input(reply_obj->Reply_And,
-				 Config.getCStringDefault("replyexand", "", set_default));
-	fl_set_button(reply_obj->Reply_Exclude,
-				  Config.getIntDefault("replyex", 1, set_default));
-	fl_set_input(reply_obj->Forward_Str,
-				 Config.getCStringDefault("fwdstr", "-----Fwd: %i-----%n%n",
-										 set_default));
+	fl_set_input(reply_obj->Reply_Prefix, Config.get("prefix", ">", set_default).c_str());
+	fl_set_input(reply_obj->Reply_RePrefix, Config.get("reprefix", "RE:", set_default).c_str());
+	fl_set_input(reply_obj->Reply_FwdPrefix, Config.get("fwdprefix", "FWD:", set_default).c_str());
+	fl_set_input(reply_obj->Reply_Str, Config.get("replystr", "On %d %f wrote:%n", set_default).c_str());
+	fl_set_input(reply_obj->Reply_And, Config.get("replyexand", "", set_default).c_str());
+	fl_set_button(reply_obj->Reply_Exclude, Config.getIntDefault("replyex", 1, set_default));
+	fl_set_input(reply_obj->Forward_Str, Config.get("fwdstr", "-----Fwd: %i-----%n%n",
+										 set_default).c_str());
 	fl_set_button(reply_obj->Reply_Charset,
 				  Config.getIntDefault("replykeepchset", 0, set_default));
 	fl_set_button(reply_obj->Reply_Keep,
