@@ -1,10 +1,10 @@
-/* $Id: sign.cpp,v 1.7 2002/01/26 03:14:55 fesnel Exp $ */
+/* $Id: sign.cpp,v 1.11 2004/01/02 04:05:37 fesnel Exp $ */
 /*******************************************************************************
  *   This program is part of the XFMail email client.                          *
  *                                                                             *
  *   Copyright : (C) 1995-1998 Gennady B. Sorokopud (gena@NetVision.net.il)    *
  *               (C) 1995 Ugen. J. S. Antsilevich (ugen@latte.worldbank.org)   *
- *               (C) 1998-2002 by the Archimedes Project                       *
+ *               (C) 1998-2004 by the Archimedes Project                       *
  *                   http://sourceforge.net/projects/archimedes                *
  *                                                                             *
  *             --------------------------------------------                    *
@@ -84,9 +84,7 @@ This message was sent by XFMail\n\
 static FD_Sign_Edit *sign_obj;
 static int ready = 0;
 
-void load_signatures();
-void save_signatures();
-void free_signatures();
+static void save_signatures();
 
 void sign_changed() {
 	if(!fl_get_textedit_bufchanged(sign_obj->Sign_Enter))
@@ -99,7 +97,7 @@ void sign_changed() {
 	save_signatures();
 }
 
-void save_signatures() {
+static void save_signatures() {
 	char buf[255], stmp[16];
 	struct _xf_sign *sign;
 	int i;
@@ -155,7 +153,7 @@ void load_signatures() {
 		sprintf(stmp, "sign%d", i);
 		if(!Config.exist(stmp))
 			continue;
-		strcpy(buf, Config.getCString(stmp, ""));
+		strcpy(buf, Config.get(stmp, "").c_str());
 		if((sign = (struct _xf_sign *) malloc(sizeof(struct _xf_sign))) ==
 		   NULL) {
 			display_msg(MSG_FATAL, "load signatures", "Malloc failed");
@@ -400,7 +398,7 @@ void delete_signature() {
 		sprintf(stmp, "sign%d", i);
 		if(!Config.exist(stmp))
 			continue;
-		p = Config.getCString(stmp, "");
+		p = const_cast<char *>(Config.get(stmp, "").c_str());
 		if(strncmp(p, ed_sign->name, strlen(ed_sign->name)))
 			continue;
 
@@ -627,8 +625,7 @@ void sign_edit() {
 	fl_addto_choice(sign_obj->Sign_Att, "Don't add|Before|After");
 	fl_set_choice(sign_obj->Sign_Att,
 				  Config.getInt("sattach", 2));
-	fl_set_input(sign_obj->Sign_Fortune,
-				 Config.getCString("fortune", "/usr/games/fortune -s"));
+	fl_set_input(sign_obj->Sign_Fortune, Config.get("fortune", "/usr/games/fortune -s").c_str());
 	fl_set_button(sign_obj->Sign_Prefix,
 				  Config.getInt("signprefix", 1));
 	fl_set_pixmapbutton_data(sign_obj->Sign_Exit, exit_xpm);
@@ -656,7 +653,7 @@ void sign_edit() {
 	Config.setFlags("signgeom", CF_NOTCHANGED);
 	w = 660;
 	h = 330;
-	sscanf(Config.getCString("signgeom", ""), "%d %d", &w, &h);
+	sscanf(Config.get("signgeom", "").c_str(), "%d %d", &w, &h);
 	fl_set_form_minsize(sign_obj->Sign_Edit, 400, 200);
 	fl_set_form_maxsize(sign_obj->Sign_Edit, 760, 330);
 	fl_set_form_size(sign_obj->Sign_Edit, w, h);
