@@ -1,10 +1,10 @@
-/* $Id: sort.cpp,v 1.9 2002/01/26 03:14:55 fesnel Exp $ */
+/* $Id: sort.cpp,v 1.14 2004/01/02 04:05:37 fesnel Exp $ */
 /*******************************************************************************
  *   This program is part of the XFMail email client.                          *
  *                                                                             *
  *   Copyright : (C) 1995-1998 Gennady B. Sorokopud (gena@NetVision.net.il)    *
  *               (C) 1995 Ugen. J. S. Antsilevich (ugen@latte.worldbank.org)   *
- *               (C) 1998-2002 by the Archimedes Project                       *
+ *               (C) 1998-2004 by the Archimedes Project                       *
  *                   http://sourceforge.net/projects/archimedes                *
  *                                                                             *
  *             --------------------------------------------                    *
@@ -80,7 +80,8 @@ void sort_conf(int set_default, FD_config_display * form) {
 						 set_default);
 	folder_sort =
 	Config.getIntDefault("fsort", BY_NAME | MSG_ASCEND,
-						 set_default); switch(sort_type & 0x0f) {
+		set_default);
+	switch(sort_type & 0x0f) {
 		case NO_SORT:
 			fl_set_button(sort_obj->Sort_None, 1);
 			break;
@@ -303,7 +304,7 @@ void handle_sort_input(FD_config_display * form) {
 		Config.set("sort", new_sort);
 		sort_type = new_sort;
 		for(i = 0; i < (int)mailbox.size(); i++) {
-			if(mailbox[i]->sort == new_sort)
+			if(mailbox[i]->sort == (int)new_sort)
 				mailbox[i]->sort = -1;
 		}
 
@@ -440,6 +441,11 @@ void set_fld_values(struct _mail_folder *fld) {
 	else
 		fl_set_input(fold_obj->Folder_From, "");
 
+	if(fld->To)
+		fl_set_input(fold_obj->Folder_To, get_full_addr_line(fld->To));
+	else
+		fl_set_input(fold_obj->Folder_To, "");
+
 	return;
 }
 
@@ -612,6 +618,13 @@ void folder_conf(struct _mail_folder *fld) {
 	else
 		fld->From = NULL;
 
+	discard_address(fld->To);
+	p = (char *) fl_get_input(fold_obj->Folder_To);
+	if(p && *p)
+		fld->To = get_address(p, ADDR_GET_FIRST);
+	else
+		fld->To = NULL;
+
 	fl_hide_form(fold_obj->Folder);
 	fl_free_form(fold_obj->Folder);
 	fl_free(fold_obj);
