@@ -1,10 +1,10 @@
-/* $Id: view_edit.cpp,v 1.7 2002/01/26 03:14:55 fesnel Exp $ */
+/* $Id: view_edit.cpp,v 1.11 2004/01/02 04:05:37 fesnel Exp $ */
 /*******************************************************************************
  *   This program is part of the XFMail email client.                          *
  *                                                                             *
  *   Copyright : (C) 1995-1998 Gennady B. Sorokopud (gena@NetVision.net.il)    *
  *               (C) 1995 Ugen. J. S. Antsilevich (ugen@latte.worldbank.org)   *
- *               (C) 1998-2002 by the Archimedes Project                       *
+ *               (C) 1998-2004 by the Archimedes Project                       *
  *                   http://sourceforge.net/projects/archimedes                *
  *                                                                             *
  *             --------------------------------------------                    *
@@ -138,16 +138,9 @@ void view_conf(int set_default, FD_config_viewedit * form) {
 														Config.getIntDefault(
 														 "viewrap", 80,
 														 set_default)));
-	fl_set_input(view_obj->View_EView,
-				 Config.getCStringDefault("extview",
-										 "/usr/bin/X11/xedit",
-										 set_default));
-	fl_set_input(view_obj->View_URL,
-				 Config.getCStringDefault("urlview", "",
-										 set_default));
-	fl_set_input(view_obj->View_FTP,
-				 Config.getCStringDefault("ftprog", "",
-										 set_default));
+	fl_set_input(view_obj->View_EView, Config.get("extview", "/usr/bin/X11/xedit", set_default).c_str());
+	fl_set_input(view_obj->View_URL, Config.get("urlview", "", set_default).c_str());
+	fl_set_input(view_obj->View_FTP, Config.get("ftprog", "", set_default).c_str());
 	headcolor = Config.getIntDefault("headcolor", FL_RED, set_default);
 	fl_set_button(view_obj->View_Header,
 				  Config.getIntDefault("sheader", 0,
@@ -202,10 +195,7 @@ void edit_conf(int set_default, FD_config_viewedit * form) {
 	fl_set_button(edit_obj->Edit_Paste_Cursor,
 				  Config.getIntDefault("editpastecur", 1,
 									   set_default));
-	fl_set_input(edit_obj->Edit_EEdit,
-				 Config.getCStringDefault("extedit",
-										 "/usr/bin/X11/xedit",
-										 set_default));
+	fl_set_input(edit_obj->Edit_EEdit, Config.get("extedit", "/usr/bin/X11/xedit", set_default).c_str());
 }
 void handle_edit_input(FD_config_viewedit * form) {
 	int wrap;
@@ -260,7 +250,8 @@ int file_view(char *file, struct _proc_info *pinfo) {
 	struct _proc_info *npinfo;
 	FL_OBJECT *obj;
 	FL_FORM *viewform;
-	int i, added, w, h;
+	size_t i;
+	int added, w, h;
 	char command[255], *e;
 
 	if(!file)
@@ -268,7 +259,7 @@ int file_view(char *file, struct _proc_info *pinfo) {
 
 	strcpy(viewfile, file);
 	if(!Config.getInt("intview", 0)) {
-		e = Config.getCString("extview", "/usr/bin/X11/xedit");
+		e = const_cast<char *>(Config.get("extview", "/usr/bin/X11/xedit").c_str());
 		command[0] = '\0';
 		added = 0;
 		for(i = 0; i < strlen(e); i++) {
@@ -330,8 +321,7 @@ int file_view(char *file, struct _proc_info *pinfo) {
 	fl_set_form_atclose(viewform, close_intview_form, viewform);
 	fl_end_form();
 	fl_set_form_minsize(viewform, 600, 300);
-	sscanf(Config.getCString("msgformsize", "800 600"), "%d %d",
-		   &w, &h);
+	sscanf(Config.get("msgformsize", "800 600").c_str(), "%d %d", &w, &h);
 	if(Config.getInt("wplace", 1))
 		fl_set_initial_placement(viewform, 100, 150, w, h);
 	else
